# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import account_pb2 as gateway_dot_account__pb2
from . import api_key_pb2 as gateway_dot_api__key__pb2
from . import audit_log_pb2 as gateway_dot_audit__log__pb2
from . import aws_iam_role_binding_pb2 as gateway_dot_aws__iam__role__binding__pb2
from . import batch_inference_job_pb2 as gateway_dot_batch__inference__job__pb2
from . import batch_job_pb2 as gateway_dot_batch__job__pb2
from . import billing_pb2 as gateway_dot_billing__pb2
from . import cluster_pb2 as gateway_dot_cluster__pb2
from . import dataset_pb2 as gateway_dot_dataset__pb2
from . import dataset_validation_job_pb2 as gateway_dot_dataset__validation__job__pb2
from . import deployed_model_pb2 as gateway_dot_deployed__model__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import deployment_template_pb2 as gateway_dot_deployment__template__pb2
from . import eagle_training_job_pb2 as gateway_dot_eagle__training__job__pb2
from . import environment_pb2 as gateway_dot_environment__pb2
from . import evaluation_job_pb2 as gateway_dot_evaluation__job__pb2
from . import evaluation_pb2 as gateway_dot_evaluation__pb2
from . import evaluator_pb2 as gateway_dot_evaluator__pb2
from . import feature_flag_pb2 as gateway_dot_feature__flag__pb2
from . import fine_tuning_job_pb2 as gateway_dot_fine__tuning__job__pb2
from . import inference_log_pb2 as gateway_dot_inference__log__pb2
from . import model_pb2 as gateway_dot_model__pb2
from . import node_pool_binding_pb2 as gateway_dot_node__pool__binding__pb2
from . import node_pool_pb2 as gateway_dot_node__pool__pb2
from . import peft_merge_job_pb2 as gateway_dot_peft__merge__job__pb2
from . import quota_pb2 as gateway_dot_quota__pb2
from . import reinforcement_fine_tuning_epoch_pb2 as gateway_dot_reinforcement__fine__tuning__epoch__pb2
from . import reinforcement_fine_tuning_job_pb2 as gateway_dot_reinforcement__fine__tuning__job__pb2
from . import reservation_pb2 as gateway_dot_reservation__pb2
from . import rlor_trainer_job_pb2 as gateway_dot_rlor__trainer__job__pb2
from . import secret_pb2 as gateway_dot_secret__pb2
from . import sign_in_pb2 as gateway_dot_sign__in__pb2
from . import snapshot_pb2 as gateway_dot_snapshot__pb2
from . import supervised_fine_tuning_job_pb2 as gateway_dot_supervised__fine__tuning__job__pb2
from . import user_pb2 as gateway_dot_user__pb2
from ..google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in gateway/gateway_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class GatewayStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOAuthArguments = channel.unary_unary(
                '/gateway.Gateway/GetOAuthArguments',
                request_serializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsRequest.SerializeToString,
                response_deserializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsResponse.FromString,
                _registered_method=True)
        self.CreateAccount = channel.unary_unary(
                '/gateway.Gateway/CreateAccount',
                request_serializer=gateway_dot_account__pb2.CreateAccountRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.Account.FromString,
                _registered_method=True)
        self.GetAccount = channel.unary_unary(
                '/gateway.Gateway/GetAccount',
                request_serializer=gateway_dot_account__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.Account.FromString,
                _registered_method=True)
        self.ListAccounts = channel.unary_unary(
                '/gateway.Gateway/ListAccounts',
                request_serializer=gateway_dot_account__pb2.ListAccountsRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.ListAccountsResponse.FromString,
                _registered_method=True)
        self.UpdateAccount = channel.unary_unary(
                '/gateway.Gateway/UpdateAccount',
                request_serializer=gateway_dot_account__pb2.UpdateAccountRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.Account.FromString,
                _registered_method=True)
        self.DeleteAccount = channel.unary_unary(
                '/gateway.Gateway/DeleteAccount',
                request_serializer=gateway_dot_account__pb2.DeleteAccountRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetBalance = channel.unary_unary(
                '/gateway.Gateway/GetBalance',
                request_serializer=gateway_dot_billing__pb2.GetBalanceRequest.SerializeToString,
                response_deserializer=gateway_dot_billing__pb2.Balance.FromString,
                _registered_method=True)
        self.ListPaymentMethods = channel.unary_unary(
                '/gateway.Gateway/ListPaymentMethods',
                request_serializer=gateway_dot_billing__pb2.ListPaymentMethodsRequest.SerializeToString,
                response_deserializer=gateway_dot_billing__pb2.ListPaymentMethodsResponse.FromString,
                _registered_method=True)
        self.ListCosts = channel.unary_unary(
                '/gateway.Gateway/ListCosts',
                request_serializer=gateway_dot_billing__pb2.ListCostsRequest.SerializeToString,
                response_deserializer=gateway_dot_billing__pb2.ListCostsResponse.FromString,
                _registered_method=True)
        self.ListInvoices = channel.unary_unary(
                '/gateway.Gateway/ListInvoices',
                request_serializer=gateway_dot_billing__pb2.ListInvoicesRequest.SerializeToString,
                response_deserializer=gateway_dot_billing__pb2.ListInvoicesResponse.FromString,
                _registered_method=True)
        self.ExportBillingMetrics = channel.unary_unary(
                '/gateway.Gateway/ExportBillingMetrics',
                request_serializer=gateway_dot_billing__pb2.ExportBillingMetricsRequest.SerializeToString,
                response_deserializer=gateway_dot_billing__pb2.ExportBillingMetricsResponse.FromString,
                _registered_method=True)
        self.GetTotalHistoricalSpend = channel.unary_unary(
                '/gateway.Gateway/GetTotalHistoricalSpend',
                request_serializer=gateway_dot_billing__pb2.GetTotalHistoricalSpendRequest.SerializeToString,
                response_deserializer=gateway_dot_billing__pb2.GetTotalHistoricalSpendResponse.FromString,
                _registered_method=True)
        self.CreateBatchJob = channel.unary_unary(
                '/gateway.Gateway/CreateBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.CreateBatchJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.BatchJob.FromString,
                _registered_method=True)
        self.GetBatchJob = channel.unary_unary(
                '/gateway.Gateway/GetBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.GetBatchJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.BatchJob.FromString,
                _registered_method=True)
        self.ListBatchJobs = channel.unary_unary(
                '/gateway.Gateway/ListBatchJobs',
                request_serializer=gateway_dot_batch__job__pb2.ListBatchJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.ListBatchJobsResponse.FromString,
                _registered_method=True)
        self.UpdateBatchJob = channel.unary_unary(
                '/gateway.Gateway/UpdateBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.UpdateBatchJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.BatchJob.FromString,
                _registered_method=True)
        self.DeleteBatchJob = channel.unary_unary(
                '/gateway.Gateway/DeleteBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.DeleteBatchJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.BatchDeleteBatchJobs = channel.unary_unary(
                '/gateway.Gateway/BatchDeleteBatchJobs',
                request_serializer=gateway_dot_batch__job__pb2.BatchDeleteBatchJobsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CancelBatchJob = channel.unary_unary(
                '/gateway.Gateway/CancelBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.CancelBatchJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateCluster = channel.unary_unary(
                '/gateway.Gateway/CreateCluster',
                request_serializer=gateway_dot_cluster__pb2.CreateClusterRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.Cluster.FromString,
                _registered_method=True)
        self.GetCluster = channel.unary_unary(
                '/gateway.Gateway/GetCluster',
                request_serializer=gateway_dot_cluster__pb2.GetClusterRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.Cluster.FromString,
                _registered_method=True)
        self.ListClusters = channel.unary_unary(
                '/gateway.Gateway/ListClusters',
                request_serializer=gateway_dot_cluster__pb2.ListClustersRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.ListClustersResponse.FromString,
                _registered_method=True)
        self.UpdateCluster = channel.unary_unary(
                '/gateway.Gateway/UpdateCluster',
                request_serializer=gateway_dot_cluster__pb2.UpdateClusterRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.Cluster.FromString,
                _registered_method=True)
        self.DeleteCluster = channel.unary_unary(
                '/gateway.Gateway/DeleteCluster',
                request_serializer=gateway_dot_cluster__pb2.DeleteClusterRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetClusterConnectionInfo = channel.unary_unary(
                '/gateway.Gateway/GetClusterConnectionInfo',
                request_serializer=gateway_dot_cluster__pb2.GetClusterConnectionInfoRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.ClusterConnectionInfo.FromString,
                _registered_method=True)
        self.CreateEnvironment = channel.unary_unary(
                '/gateway.Gateway/CreateEnvironment',
                request_serializer=gateway_dot_environment__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.Environment.FromString,
                _registered_method=True)
        self.GetEnvironment = channel.unary_unary(
                '/gateway.Gateway/GetEnvironment',
                request_serializer=gateway_dot_environment__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.Environment.FromString,
                _registered_method=True)
        self.ListEnvironments = channel.unary_unary(
                '/gateway.Gateway/ListEnvironments',
                request_serializer=gateway_dot_environment__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.ListEnvironmentsResponse.FromString,
                _registered_method=True)
        self.UpdateEnvironment = channel.unary_unary(
                '/gateway.Gateway/UpdateEnvironment',
                request_serializer=gateway_dot_environment__pb2.UpdateEnvironmentRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.Environment.FromString,
                _registered_method=True)
        self.DeleteEnvironment = channel.unary_unary(
                '/gateway.Gateway/DeleteEnvironment',
                request_serializer=gateway_dot_environment__pb2.DeleteEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.BatchDeleteEnvironments = channel.unary_unary(
                '/gateway.Gateway/BatchDeleteEnvironments',
                request_serializer=gateway_dot_environment__pb2.BatchDeleteEnvironmentsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.ConnectEnvironment = channel.unary_unary(
                '/gateway.Gateway/ConnectEnvironment',
                request_serializer=gateway_dot_environment__pb2.ConnectEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DisconnectEnvironment = channel.unary_unary(
                '/gateway.Gateway/DisconnectEnvironment',
                request_serializer=gateway_dot_environment__pb2.DisconnectEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetFeatureFlag = channel.unary_unary(
                '/gateway.Gateway/GetFeatureFlag',
                request_serializer=gateway_dot_feature__flag__pb2.GetFeatureFlagRequest.SerializeToString,
                response_deserializer=gateway_dot_feature__flag__pb2.FeatureFlag.FromString,
                _registered_method=True)
        self.ListFeatureFlags = channel.unary_unary(
                '/gateway.Gateway/ListFeatureFlags',
                request_serializer=gateway_dot_feature__flag__pb2.ListFeatureFlagsRequest.SerializeToString,
                response_deserializer=gateway_dot_feature__flag__pb2.ListFeatureFlagsResponse.FromString,
                _registered_method=True)
        self.CreateSnapshot = channel.unary_unary(
                '/gateway.Gateway/CreateSnapshot',
                request_serializer=gateway_dot_snapshot__pb2.CreateSnapshotRequest.SerializeToString,
                response_deserializer=gateway_dot_snapshot__pb2.Snapshot.FromString,
                _registered_method=True)
        self.GetSnapshot = channel.unary_unary(
                '/gateway.Gateway/GetSnapshot',
                request_serializer=gateway_dot_snapshot__pb2.GetSnapshotRequest.SerializeToString,
                response_deserializer=gateway_dot_snapshot__pb2.Snapshot.FromString,
                _registered_method=True)
        self.ListSnapshots = channel.unary_unary(
                '/gateway.Gateway/ListSnapshots',
                request_serializer=gateway_dot_snapshot__pb2.ListSnapshotsRequest.SerializeToString,
                response_deserializer=gateway_dot_snapshot__pb2.ListSnapshotsResponse.FromString,
                _registered_method=True)
        self.DeleteSnapshot = channel.unary_unary(
                '/gateway.Gateway/DeleteSnapshot',
                request_serializer=gateway_dot_snapshot__pb2.DeleteSnapshotRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetBatchJobLogs = channel.unary_unary(
                '/gateway.Gateway/GetBatchJobLogs',
                request_serializer=gateway_dot_batch__job__pb2.GetBatchJobLogsRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.GetBatchJobLogsResponse.FromString,
                _registered_method=True)
        self.CreateNodePool = channel.unary_unary(
                '/gateway.Gateway/CreateNodePool',
                request_serializer=gateway_dot_node__pool__pb2.CreateNodePoolRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePool.FromString,
                _registered_method=True)
        self.GetNodePool = channel.unary_unary(
                '/gateway.Gateway/GetNodePool',
                request_serializer=gateway_dot_node__pool__pb2.GetNodePoolRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePool.FromString,
                _registered_method=True)
        self.ListNodePools = channel.unary_unary(
                '/gateway.Gateway/ListNodePools',
                request_serializer=gateway_dot_node__pool__pb2.ListNodePoolsRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.ListNodePoolsResponse.FromString,
                _registered_method=True)
        self.UpdateNodePool = channel.unary_unary(
                '/gateway.Gateway/UpdateNodePool',
                request_serializer=gateway_dot_node__pool__pb2.UpdateNodePoolRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePool.FromString,
                _registered_method=True)
        self.DeleteNodePool = channel.unary_unary(
                '/gateway.Gateway/DeleteNodePool',
                request_serializer=gateway_dot_node__pool__pb2.DeleteNodePoolRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.BatchDeleteNodePools = channel.unary_unary(
                '/gateway.Gateway/BatchDeleteNodePools',
                request_serializer=gateway_dot_node__pool__pb2.BatchDeleteNodePoolsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetNodePoolStats = channel.unary_unary(
                '/gateway.Gateway/GetNodePoolStats',
                request_serializer=gateway_dot_node__pool__pb2.GetNodePoolStatsRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePoolStats.FromString,
                _registered_method=True)
        self.CreateUser = channel.unary_unary(
                '/gateway.Gateway/CreateUser',
                request_serializer=gateway_dot_user__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.GetUser = channel.unary_unary(
                '/gateway.Gateway/GetUser',
                request_serializer=gateway_dot_user__pb2.GetUserRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.ListUsers = channel.unary_unary(
                '/gateway.Gateway/ListUsers',
                request_serializer=gateway_dot_user__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.ListUsersResponse.FromString,
                _registered_method=True)
        self.UpdateUser = channel.unary_unary(
                '/gateway.Gateway/UpdateUser',
                request_serializer=gateway_dot_user__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.DeleteUser = channel.unary_unary(
                '/gateway.Gateway/DeleteUser',
                request_serializer=gateway_dot_user__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.ListAuditLogs = channel.unary_unary(
                '/gateway.Gateway/ListAuditLogs',
                request_serializer=gateway_dot_audit__log__pb2.ListAuditLogsRequest.SerializeToString,
                response_deserializer=gateway_dot_audit__log__pb2.ListAuditLogsResponse.FromString,
                _registered_method=True)
        self.CreateApiKey = channel.unary_unary(
                '/gateway.Gateway/CreateApiKey',
                request_serializer=gateway_dot_api__key__pb2.CreateApiKeyRequest.SerializeToString,
                response_deserializer=gateway_dot_api__key__pb2.ApiKey.FromString,
                _registered_method=True)
        self.ListApiKeys = channel.unary_unary(
                '/gateway.Gateway/ListApiKeys',
                request_serializer=gateway_dot_api__key__pb2.ListApiKeysRequest.SerializeToString,
                response_deserializer=gateway_dot_api__key__pb2.ListApiKeysResponse.FromString,
                _registered_method=True)
        self.DeleteApiKey = channel.unary_unary(
                '/gateway.Gateway/DeleteApiKey',
                request_serializer=gateway_dot_api__key__pb2.DeleteApiKeyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetInternalApiKey = channel.unary_unary(
                '/gateway.Gateway/GetInternalApiKey',
                request_serializer=gateway_dot_api__key__pb2.GetInternalApiKeyRequest.SerializeToString,
                response_deserializer=gateway_dot_api__key__pb2.ApiKey.FromString,
                _registered_method=True)
        self.CreateModel = channel.unary_unary(
                '/gateway.Gateway/CreateModel',
                request_serializer=gateway_dot_model__pb2.CreateModelRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.Model.FromString,
                _registered_method=True)
        self.GetModel = channel.unary_unary(
                '/gateway.Gateway/GetModel',
                request_serializer=gateway_dot_model__pb2.GetModelRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.Model.FromString,
                _registered_method=True)
        self.ListModels = channel.unary_unary(
                '/gateway.Gateway/ListModels',
                request_serializer=gateway_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.ListModelsResponse.FromString,
                _registered_method=True)
        self.ListServerlessLoraModels = channel.unary_unary(
                '/gateway.Gateway/ListServerlessLoraModels',
                request_serializer=gateway_dot_model__pb2.ListServerlessLoraModelsRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.ListServerlessLoraModelsResponse.FromString,
                _registered_method=True)
        self.UpdateModel = channel.unary_unary(
                '/gateway.Gateway/UpdateModel',
                request_serializer=gateway_dot_model__pb2.UpdateModelRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.Model.FromString,
                _registered_method=True)
        self.DeleteModel = channel.unary_unary(
                '/gateway.Gateway/DeleteModel',
                request_serializer=gateway_dot_model__pb2.DeleteModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetModelUploadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetModelUploadEndpoint',
                request_serializer=gateway_dot_model__pb2.GetModelUploadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.GetModelUploadEndpointResponse.FromString,
                _registered_method=True)
        self.GetModelDownloadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetModelDownloadEndpoint',
                request_serializer=gateway_dot_model__pb2.GetModelDownloadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.GetModelDownloadEndpointResponse.FromString,
                _registered_method=True)
        self.ValidateModelUpload = channel.unary_unary(
                '/gateway.Gateway/ValidateModelUpload',
                request_serializer=gateway_dot_model__pb2.ValidateModelUploadRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.ValidateModelConfig = channel.unary_unary(
                '/gateway.Gateway/ValidateModelConfig',
                request_serializer=gateway_dot_model__pb2.ValidateModelConfigRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.ImportModel = channel.unary_unary(
                '/gateway.Gateway/ImportModel',
                request_serializer=gateway_dot_model__pb2.ImportModelRequest.SerializeToString,
                response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
                _registered_method=True)
        self.CreateDeployment = channel.unary_unary(
                '/gateway.Gateway/CreateDeployment',
                request_serializer=gateway_dot_deployment__pb2.CreateDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                _registered_method=True)
        self.GetDeployment = channel.unary_unary(
                '/gateway.Gateway/GetDeployment',
                request_serializer=gateway_dot_deployment__pb2.GetDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                _registered_method=True)
        self.ListDeployments = channel.unary_unary(
                '/gateway.Gateway/ListDeployments',
                request_serializer=gateway_dot_deployment__pb2.ListDeploymentsRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.ListDeploymentsResponse.FromString,
                _registered_method=True)
        self.UpdateDeployment = channel.unary_unary(
                '/gateway.Gateway/UpdateDeployment',
                request_serializer=gateway_dot_deployment__pb2.UpdateDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                _registered_method=True)
        self.DeleteDeployment = channel.unary_unary(
                '/gateway.Gateway/DeleteDeployment',
                request_serializer=gateway_dot_deployment__pb2.DeleteDeploymentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.UndeleteDeployment = channel.unary_unary(
                '/gateway.Gateway/UndeleteDeployment',
                request_serializer=gateway_dot_deployment__pb2.UndeleteDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                _registered_method=True)
        self.ScaleDeployment = channel.unary_unary(
                '/gateway.Gateway/ScaleDeployment',
                request_serializer=gateway_dot_deployment__pb2.ScaleDeploymentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetDeploymentMetrics = channel.unary_unary(
                '/gateway.Gateway/GetDeploymentMetrics',
                request_serializer=gateway_dot_deployment__pb2.GetDeploymentMetricsRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.GetDeploymentMetricsResponse.FromString,
                _registered_method=True)
        self.CreateDeploymentTemplate = channel.unary_unary(
                '/gateway.Gateway/CreateDeploymentTemplate',
                request_serializer=gateway_dot_deployment__template__pb2.CreateDeploymentTemplateRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__template__pb2.DeploymentTemplate.FromString,
                _registered_method=True)
        self.GetDeploymentTemplate = channel.unary_unary(
                '/gateway.Gateway/GetDeploymentTemplate',
                request_serializer=gateway_dot_deployment__template__pb2.GetDeploymentTemplateRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__template__pb2.DeploymentTemplate.FromString,
                _registered_method=True)
        self.ListDeploymentTemplates = channel.unary_unary(
                '/gateway.Gateway/ListDeploymentTemplates',
                request_serializer=gateway_dot_deployment__template__pb2.ListDeploymentTemplatesRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__template__pb2.ListDeploymentTemplatesResponse.FromString,
                _registered_method=True)
        self.UpdateDeploymentTemplate = channel.unary_unary(
                '/gateway.Gateway/UpdateDeploymentTemplate',
                request_serializer=gateway_dot_deployment__template__pb2.UpdateDeploymentTemplateRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__template__pb2.DeploymentTemplate.FromString,
                _registered_method=True)
        self.DeleteDeploymentTemplate = channel.unary_unary(
                '/gateway.Gateway/DeleteDeploymentTemplate',
                request_serializer=gateway_dot_deployment__template__pb2.DeleteDeploymentTemplateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateDeployedModel = channel.unary_unary(
                '/gateway.Gateway/CreateDeployedModel',
                request_serializer=gateway_dot_deployed__model__pb2.CreateDeployedModelRequest.SerializeToString,
                response_deserializer=gateway_dot_deployed__model__pb2.DeployedModel.FromString,
                _registered_method=True)
        self.GetDeployedModel = channel.unary_unary(
                '/gateway.Gateway/GetDeployedModel',
                request_serializer=gateway_dot_deployed__model__pb2.GetDeployedModelRequest.SerializeToString,
                response_deserializer=gateway_dot_deployed__model__pb2.DeployedModel.FromString,
                _registered_method=True)
        self.ListDeployedModels = channel.unary_unary(
                '/gateway.Gateway/ListDeployedModels',
                request_serializer=gateway_dot_deployed__model__pb2.ListDeployedModelsRequest.SerializeToString,
                response_deserializer=gateway_dot_deployed__model__pb2.ListDeployedModelsResponse.FromString,
                _registered_method=True)
        self.UpdateDeployedModel = channel.unary_unary(
                '/gateway.Gateway/UpdateDeployedModel',
                request_serializer=gateway_dot_deployed__model__pb2.UpdateDeployedModelRequest.SerializeToString,
                response_deserializer=gateway_dot_deployed__model__pb2.DeployedModel.FromString,
                _registered_method=True)
        self.DeleteDeployedModel = channel.unary_unary(
                '/gateway.Gateway/DeleteDeployedModel',
                request_serializer=gateway_dot_deployed__model__pb2.DeleteDeployedModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateAwsIamRoleBinding = channel.unary_unary(
                '/gateway.Gateway/CreateAwsIamRoleBinding',
                request_serializer=gateway_dot_aws__iam__role__binding__pb2.CreateAwsIamRoleBindingRequest.SerializeToString,
                response_deserializer=gateway_dot_aws__iam__role__binding__pb2.AwsIamRoleBinding.FromString,
                _registered_method=True)
        self.ListAwsIamRoleBindings = channel.unary_unary(
                '/gateway.Gateway/ListAwsIamRoleBindings',
                request_serializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsRequest.SerializeToString,
                response_deserializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsResponse.FromString,
                _registered_method=True)
        self.DeleteAwsIamRoleBinding = channel.unary_unary(
                '/gateway.Gateway/DeleteAwsIamRoleBinding',
                request_serializer=gateway_dot_aws__iam__role__binding__pb2.DeleteAwsIamRoleBindingRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateNodePoolBinding = channel.unary_unary(
                '/gateway.Gateway/CreateNodePoolBinding',
                request_serializer=gateway_dot_node__pool__binding__pb2.CreateNodePoolBindingRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__binding__pb2.NodePoolBinding.FromString,
                _registered_method=True)
        self.ListNodePoolBindings = channel.unary_unary(
                '/gateway.Gateway/ListNodePoolBindings',
                request_serializer=gateway_dot_node__pool__binding__pb2.ListNodePoolBindingsRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__binding__pb2.ListNodePoolBindingsResponse.FromString,
                _registered_method=True)
        self.DeleteNodePoolBinding = channel.unary_unary(
                '/gateway.Gateway/DeleteNodePoolBinding',
                request_serializer=gateway_dot_node__pool__binding__pb2.DeleteNodePoolBindingRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateDataset = channel.unary_unary(
                '/gateway.Gateway/CreateDataset',
                request_serializer=gateway_dot_dataset__pb2.CreateDatasetRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.Dataset.FromString,
                _registered_method=True)
        self.GetDataset = channel.unary_unary(
                '/gateway.Gateway/GetDataset',
                request_serializer=gateway_dot_dataset__pb2.GetDatasetRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.Dataset.FromString,
                _registered_method=True)
        self.ListDatasets = channel.unary_unary(
                '/gateway.Gateway/ListDatasets',
                request_serializer=gateway_dot_dataset__pb2.ListDatasetsRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.ListDatasetsResponse.FromString,
                _registered_method=True)
        self.UpdateDataset = channel.unary_unary(
                '/gateway.Gateway/UpdateDataset',
                request_serializer=gateway_dot_dataset__pb2.UpdateDatasetRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.Dataset.FromString,
                _registered_method=True)
        self.DeleteDataset = channel.unary_unary(
                '/gateway.Gateway/DeleteDataset',
                request_serializer=gateway_dot_dataset__pb2.DeleteDatasetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.UploadDataset = channel.unary_unary(
                '/gateway.Gateway/UploadDataset',
                request_serializer=gateway_dot_dataset__pb2.UploadDatasetRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.UploadDatasetResponse.FromString,
                _registered_method=True)
        self.GetDatasetUploadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetDatasetUploadEndpoint',
                request_serializer=gateway_dot_dataset__pb2.GetDatasetUploadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.GetDatasetUploadEndpointResponse.FromString,
                _registered_method=True)
        self.ValidateDatasetUpload = channel.unary_unary(
                '/gateway.Gateway/ValidateDatasetUpload',
                request_serializer=gateway_dot_dataset__pb2.ValidateDatasetUploadRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetDatasetDownloadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetDatasetDownloadEndpoint',
                request_serializer=gateway_dot_dataset__pb2.GetDatasetDownloadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.GetDatasetDownloadEndpointResponse.FromString,
                _registered_method=True)
        self.PreviewDataset = channel.unary_unary(
                '/gateway.Gateway/PreviewDataset',
                request_serializer=gateway_dot_dataset__pb2.PreviewDatasetRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__pb2.PreviewDatasetResponse.FromString,
                _registered_method=True)
        self.CreateEvaluator = channel.unary_unary(
                '/gateway.Gateway/CreateEvaluator',
                request_serializer=gateway_dot_evaluator__pb2.CreateEvaluatorRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluator__pb2.Evaluator.FromString,
                _registered_method=True)
        self.GetEvaluator = channel.unary_unary(
                '/gateway.Gateway/GetEvaluator',
                request_serializer=gateway_dot_evaluator__pb2.GetEvaluatorRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluator__pb2.Evaluator.FromString,
                _registered_method=True)
        self.ListEvaluators = channel.unary_unary(
                '/gateway.Gateway/ListEvaluators',
                request_serializer=gateway_dot_evaluator__pb2.ListEvaluatorsRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluator__pb2.ListEvaluatorsResponse.FromString,
                _registered_method=True)
        self.DeleteEvaluator = channel.unary_unary(
                '/gateway.Gateway/DeleteEvaluator',
                request_serializer=gateway_dot_evaluator__pb2.DeleteEvaluatorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateEvaluation = channel.unary_unary(
                '/gateway.Gateway/CreateEvaluation',
                request_serializer=gateway_dot_evaluation__pb2.CreateEvaluationRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__pb2.Evaluation.FromString,
                _registered_method=True)
        self.GetEvaluation = channel.unary_unary(
                '/gateway.Gateway/GetEvaluation',
                request_serializer=gateway_dot_evaluation__pb2.GetEvaluationRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__pb2.Evaluation.FromString,
                _registered_method=True)
        self.ListEvaluations = channel.unary_unary(
                '/gateway.Gateway/ListEvaluations',
                request_serializer=gateway_dot_evaluation__pb2.ListEvaluationsRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__pb2.ListEvaluationsResponse.FromString,
                _registered_method=True)
        self.DeleteEvaluation = channel.unary_unary(
                '/gateway.Gateway/DeleteEvaluation',
                request_serializer=gateway_dot_evaluation__pb2.DeleteEvaluationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateEvaluationJob = channel.unary_unary(
                '/gateway.Gateway/CreateEvaluationJob',
                request_serializer=gateway_dot_evaluation__job__pb2.CreateEvaluationJobRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__job__pb2.EvaluationJob.FromString,
                _registered_method=True)
        self.GetEvaluationJob = channel.unary_unary(
                '/gateway.Gateway/GetEvaluationJob',
                request_serializer=gateway_dot_evaluation__job__pb2.GetEvaluationJobRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__job__pb2.EvaluationJob.FromString,
                _registered_method=True)
        self.ListEvaluationJobs = channel.unary_unary(
                '/gateway.Gateway/ListEvaluationJobs',
                request_serializer=gateway_dot_evaluation__job__pb2.ListEvaluationJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__job__pb2.ListEvaluationJobsResponse.FromString,
                _registered_method=True)
        self.DeleteEvaluationJob = channel.unary_unary(
                '/gateway.Gateway/DeleteEvaluationJob',
                request_serializer=gateway_dot_evaluation__job__pb2.DeleteEvaluationJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/CreateFineTuningJob',
                request_serializer=gateway_dot_fine__tuning__job__pb2.CreateFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_fine__tuning__job__pb2.FineTuningJob.FromString,
                _registered_method=True)
        self.GetFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/GetFineTuningJob',
                request_serializer=gateway_dot_fine__tuning__job__pb2.GetFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_fine__tuning__job__pb2.FineTuningJob.FromString,
                _registered_method=True)
        self.ListFineTuningJobs = channel.unary_unary(
                '/gateway.Gateway/ListFineTuningJobs',
                request_serializer=gateway_dot_fine__tuning__job__pb2.ListFineTuningJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_fine__tuning__job__pb2.ListFineTuningJobsResponse.FromString,
                _registered_method=True)
        self.UpdateFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/UpdateFineTuningJob',
                request_serializer=gateway_dot_fine__tuning__job__pb2.UpdateFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_fine__tuning__job__pb2.FineTuningJob.FromString,
                _registered_method=True)
        self.DeleteFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/DeleteFineTuningJob',
                request_serializer=gateway_dot_fine__tuning__job__pb2.DeleteFineTuningJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateSupervisedFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/CreateSupervisedFineTuningJob',
                request_serializer=gateway_dot_supervised__fine__tuning__job__pb2.CreateSupervisedFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.SupervisedFineTuningJob.FromString,
                _registered_method=True)
        self.GetSupervisedFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/GetSupervisedFineTuningJob',
                request_serializer=gateway_dot_supervised__fine__tuning__job__pb2.GetSupervisedFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.SupervisedFineTuningJob.FromString,
                _registered_method=True)
        self.ListSupervisedFineTuningJobs = channel.unary_unary(
                '/gateway.Gateway/ListSupervisedFineTuningJobs',
                request_serializer=gateway_dot_supervised__fine__tuning__job__pb2.ListSupervisedFineTuningJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.ListSupervisedFineTuningJobsResponse.FromString,
                _registered_method=True)
        self.DeleteSupervisedFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/DeleteSupervisedFineTuningJob',
                request_serializer=gateway_dot_supervised__fine__tuning__job__pb2.DeleteSupervisedFineTuningJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateReinforcementFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/CreateReinforcementFineTuningJob',
                request_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.CreateReinforcementFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ReinforcementFineTuningJob.FromString,
                _registered_method=True)
        self.GetReinforcementFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/GetReinforcementFineTuningJob',
                request_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.GetReinforcementFineTuningJobRequest.SerializeToString,
                response_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ReinforcementFineTuningJob.FromString,
                _registered_method=True)
        self.ListReinforcementFineTuningJobs = channel.unary_unary(
                '/gateway.Gateway/ListReinforcementFineTuningJobs',
                request_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ListReinforcementFineTuningJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ListReinforcementFineTuningJobsResponse.FromString,
                _registered_method=True)
        self.DeleteReinforcementFineTuningJob = channel.unary_unary(
                '/gateway.Gateway/DeleteReinforcementFineTuningJob',
                request_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.DeleteReinforcementFineTuningJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateReinforcementFineTuningEpoch = channel.unary_unary(
                '/gateway.Gateway/CreateReinforcementFineTuningEpoch',
                request_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.CreateReinforcementFineTuningEpochRequest.SerializeToString,
                response_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ReinforcementFineTuningEpoch.FromString,
                _registered_method=True)
        self.GetReinforcementFineTuningEpoch = channel.unary_unary(
                '/gateway.Gateway/GetReinforcementFineTuningEpoch',
                request_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.GetReinforcementFineTuningEpochRequest.SerializeToString,
                response_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ReinforcementFineTuningEpoch.FromString,
                _registered_method=True)
        self.ListReinforcementFineTuningEpochs = channel.unary_unary(
                '/gateway.Gateway/ListReinforcementFineTuningEpochs',
                request_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ListReinforcementFineTuningEpochsRequest.SerializeToString,
                response_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ListReinforcementFineTuningEpochsResponse.FromString,
                _registered_method=True)
        self.DeleteReinforcementFineTuningEpoch = channel.unary_unary(
                '/gateway.Gateway/DeleteReinforcementFineTuningEpoch',
                request_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.DeleteReinforcementFineTuningEpochRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateRlorTrainerJob = channel.unary_unary(
                '/gateway.Gateway/CreateRlorTrainerJob',
                request_serializer=gateway_dot_rlor__trainer__job__pb2.CreateRlorTrainerJobRequest.SerializeToString,
                response_deserializer=gateway_dot_rlor__trainer__job__pb2.RlorTrainerJob.FromString,
                _registered_method=True)
        self.GetRlorTrainerJob = channel.unary_unary(
                '/gateway.Gateway/GetRlorTrainerJob',
                request_serializer=gateway_dot_rlor__trainer__job__pb2.GetRlorTrainerJobRequest.SerializeToString,
                response_deserializer=gateway_dot_rlor__trainer__job__pb2.RlorTrainerJob.FromString,
                _registered_method=True)
        self.ListRlorTrainerJobs = channel.unary_unary(
                '/gateway.Gateway/ListRlorTrainerJobs',
                request_serializer=gateway_dot_rlor__trainer__job__pb2.ListRlorTrainerJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_rlor__trainer__job__pb2.ListRlorTrainerJobsResponse.FromString,
                _registered_method=True)
        self.DeleteRlorTrainerJob = channel.unary_unary(
                '/gateway.Gateway/DeleteRlorTrainerJob',
                request_serializer=gateway_dot_rlor__trainer__job__pb2.DeleteRlorTrainerJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreatePeftMergeJob = channel.unary_unary(
                '/gateway.Gateway/CreatePeftMergeJob',
                request_serializer=gateway_dot_peft__merge__job__pb2.CreatePeftMergeJobRequest.SerializeToString,
                response_deserializer=gateway_dot_peft__merge__job__pb2.PeftMergeJob.FromString,
                _registered_method=True)
        self.GetPeftMergeJob = channel.unary_unary(
                '/gateway.Gateway/GetPeftMergeJob',
                request_serializer=gateway_dot_peft__merge__job__pb2.GetPeftMergeJobRequest.SerializeToString,
                response_deserializer=gateway_dot_peft__merge__job__pb2.PeftMergeJob.FromString,
                _registered_method=True)
        self.ListPeftMergeJobs = channel.unary_unary(
                '/gateway.Gateway/ListPeftMergeJobs',
                request_serializer=gateway_dot_peft__merge__job__pb2.ListPeftMergeJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_peft__merge__job__pb2.ListPeftMergeJobsResponse.FromString,
                _registered_method=True)
        self.DeletePeftMergeJob = channel.unary_unary(
                '/gateway.Gateway/DeletePeftMergeJob',
                request_serializer=gateway_dot_peft__merge__job__pb2.DeletePeftMergeJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetQuota = channel.unary_unary(
                '/gateway.Gateway/GetQuota',
                request_serializer=gateway_dot_quota__pb2.GetQuotaRequest.SerializeToString,
                response_deserializer=gateway_dot_quota__pb2.Quota.FromString,
                _registered_method=True)
        self.UpdateQuota = channel.unary_unary(
                '/gateway.Gateway/UpdateQuota',
                request_serializer=gateway_dot_quota__pb2.UpdateQuotaRequest.SerializeToString,
                response_deserializer=gateway_dot_quota__pb2.Quota.FromString,
                _registered_method=True)
        self.ListQuotas = channel.unary_unary(
                '/gateway.Gateway/ListQuotas',
                request_serializer=gateway_dot_quota__pb2.ListQuotasRequest.SerializeToString,
                response_deserializer=gateway_dot_quota__pb2.ListQuotasResponse.FromString,
                _registered_method=True)
        self.CreateSecret = channel.unary_unary(
                '/gateway.Gateway/CreateSecret',
                request_serializer=gateway_dot_secret__pb2.CreateSecretRequest.SerializeToString,
                response_deserializer=gateway_dot_secret__pb2.Secret.FromString,
                _registered_method=True)
        self.GetSecret = channel.unary_unary(
                '/gateway.Gateway/GetSecret',
                request_serializer=gateway_dot_secret__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=gateway_dot_secret__pb2.Secret.FromString,
                _registered_method=True)
        self.ListSecrets = channel.unary_unary(
                '/gateway.Gateway/ListSecrets',
                request_serializer=gateway_dot_secret__pb2.ListSecretsRequest.SerializeToString,
                response_deserializer=gateway_dot_secret__pb2.ListSecretsResponse.FromString,
                _registered_method=True)
        self.UpdateSecret = channel.unary_unary(
                '/gateway.Gateway/UpdateSecret',
                request_serializer=gateway_dot_secret__pb2.UpdateSecretRequest.SerializeToString,
                response_deserializer=gateway_dot_secret__pb2.Secret.FromString,
                _registered_method=True)
        self.DeleteSecret = channel.unary_unary(
                '/gateway.Gateway/DeleteSecret',
                request_serializer=gateway_dot_secret__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetReservation = channel.unary_unary(
                '/gateway.Gateway/GetReservation',
                request_serializer=gateway_dot_reservation__pb2.GetReservationRequest.SerializeToString,
                response_deserializer=gateway_dot_reservation__pb2.Reservation.FromString,
                _registered_method=True)
        self.ListReservations = channel.unary_unary(
                '/gateway.Gateway/ListReservations',
                request_serializer=gateway_dot_reservation__pb2.ListReservationsRequest.SerializeToString,
                response_deserializer=gateway_dot_reservation__pb2.ListReservationsResponse.FromString,
                _registered_method=True)
        self.PrepareModel = channel.unary_unary(
                '/gateway.Gateway/PrepareModel',
                request_serializer=gateway_dot_model__pb2.PrepareModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateBatchInferenceJob = channel.unary_unary(
                '/gateway.Gateway/CreateBatchInferenceJob',
                request_serializer=gateway_dot_batch__inference__job__pb2.CreateBatchInferenceJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__inference__job__pb2.BatchInferenceJob.FromString,
                _registered_method=True)
        self.GetBatchInferenceJob = channel.unary_unary(
                '/gateway.Gateway/GetBatchInferenceJob',
                request_serializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__inference__job__pb2.BatchInferenceJob.FromString,
                _registered_method=True)
        self.ListBatchInferenceJobs = channel.unary_unary(
                '/gateway.Gateway/ListBatchInferenceJobs',
                request_serializer=gateway_dot_batch__inference__job__pb2.ListBatchInferenceJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__inference__job__pb2.ListBatchInferenceJobsResponse.FromString,
                _registered_method=True)
        self.UpdateBatchInferenceJob = channel.unary_unary(
                '/gateway.Gateway/UpdateBatchInferenceJob',
                request_serializer=gateway_dot_batch__inference__job__pb2.UpdateBatchInferenceJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__inference__job__pb2.BatchInferenceJob.FromString,
                _registered_method=True)
        self.DeleteBatchInferenceJob = channel.unary_unary(
                '/gateway.Gateway/DeleteBatchInferenceJob',
                request_serializer=gateway_dot_batch__inference__job__pb2.DeleteBatchInferenceJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateEagleTrainingJob = channel.unary_unary(
                '/gateway.Gateway/CreateEagleTrainingJob',
                request_serializer=gateway_dot_eagle__training__job__pb2.CreateEagleTrainingJobRequest.SerializeToString,
                response_deserializer=gateway_dot_eagle__training__job__pb2.EagleTrainingJob.FromString,
                _registered_method=True)
        self.GetEagleTrainingJob = channel.unary_unary(
                '/gateway.Gateway/GetEagleTrainingJob',
                request_serializer=gateway_dot_eagle__training__job__pb2.GetEagleTrainingJobRequest.SerializeToString,
                response_deserializer=gateway_dot_eagle__training__job__pb2.EagleTrainingJob.FromString,
                _registered_method=True)
        self.ListEagleTrainingJobs = channel.unary_unary(
                '/gateway.Gateway/ListEagleTrainingJobs',
                request_serializer=gateway_dot_eagle__training__job__pb2.ListEagleTrainingJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_eagle__training__job__pb2.ListEagleTrainingJobsResponse.FromString,
                _registered_method=True)
        self.DeleteEagleTrainingJob = channel.unary_unary(
                '/gateway.Gateway/DeleteEagleTrainingJob',
                request_serializer=gateway_dot_eagle__training__job__pb2.DeleteEagleTrainingJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetBatchInferenceJobInputUploadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetBatchInferenceJobInputUploadEndpoint',
                request_serializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobInputUploadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobInputUploadEndpointResponse.FromString,
                _registered_method=True)
        self.GetBatchInferenceJobOutputDownloadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetBatchInferenceJobOutputDownloadEndpoint',
                request_serializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobOutputDownloadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobOutputDownloadEndpointResponse.FromString,
                _registered_method=True)
        self.ValidateBatchInferenceJobInputUpload = channel.unary_unary(
                '/gateway.Gateway/ValidateBatchInferenceJobInputUpload',
                request_serializer=gateway_dot_batch__inference__job__pb2.ValidateBatchInferenceJobInputUploadRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.CreateDatasetValidationJob = channel.unary_unary(
                '/gateway.Gateway/CreateDatasetValidationJob',
                request_serializer=gateway_dot_dataset__validation__job__pb2.CreateDatasetValidationJobRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__validation__job__pb2.DatasetValidationJob.FromString,
                _registered_method=True)
        self.GetDatasetValidationJob = channel.unary_unary(
                '/gateway.Gateway/GetDatasetValidationJob',
                request_serializer=gateway_dot_dataset__validation__job__pb2.GetDatasetValidationJobRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__validation__job__pb2.DatasetValidationJob.FromString,
                _registered_method=True)
        self.ListDatasetValidationJobs = channel.unary_unary(
                '/gateway.Gateway/ListDatasetValidationJobs',
                request_serializer=gateway_dot_dataset__validation__job__pb2.ListDatasetValidationJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_dataset__validation__job__pb2.ListDatasetValidationJobsResponse.FromString,
                _registered_method=True)
        self.DeleteDatasetValidationJob = channel.unary_unary(
                '/gateway.Gateway/DeleteDatasetValidationJob',
                request_serializer=gateway_dot_dataset__validation__job__pb2.DeleteDatasetValidationJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.ValidateAssertions = channel.unary_unary(
                '/gateway.Gateway/ValidateAssertions',
                request_serializer=gateway_dot_evaluation__pb2.ValidateAssertionsRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__pb2.ValidateAssertionsResponse.FromString,
                _registered_method=True)
        self.PreviewEvaluator = channel.unary_unary(
                '/gateway.Gateway/PreviewEvaluator',
                request_serializer=gateway_dot_evaluator__pb2.PreviewEvaluatorRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluator__pb2.PreviewEvaluatorResponse.FromString,
                _registered_method=True)
        self.PreviewEvaluation = channel.unary_unary(
                '/gateway.Gateway/PreviewEvaluation',
                request_serializer=gateway_dot_evaluation__pb2.PreviewEvaluationRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__pb2.PreviewEvaluationResponse.FromString,
                _registered_method=True)
        self.TestEvaluation = channel.unary_unary(
                '/gateway.Gateway/TestEvaluation',
                request_serializer=gateway_dot_evaluation__pb2.TestEvaluationRequest.SerializeToString,
                response_deserializer=gateway_dot_evaluation__pb2.PreviewEvaluationResponse.FromString,
                _registered_method=True)
        self.GetInferenceLog = channel.unary_unary(
                '/gateway.Gateway/GetInferenceLog',
                request_serializer=gateway_dot_inference__log__pb2.GetInferenceLogRequest.SerializeToString,
                response_deserializer=gateway_dot_inference__log__pb2.InferenceLog.FromString,
                _registered_method=True)
        self.ListInferenceLogs = channel.unary_unary(
                '/gateway.Gateway/ListInferenceLogs',
                request_serializer=gateway_dot_inference__log__pb2.ListInferenceLogsRequest.SerializeToString,
                response_deserializer=gateway_dot_inference__log__pb2.ListInferenceLogsResponse.FromString,
                _registered_method=True)
        self.DeleteInferenceLog = channel.unary_unary(
                '/gateway.Gateway/DeleteInferenceLog',
                request_serializer=gateway_dot_inference__log__pb2.DeleteInferenceLogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetDeploymentPrerequisites = channel.unary_unary(
                '/gateway.Gateway/GetDeploymentPrerequisites',
                request_serializer=gateway_dot_deployment__pb2.GetDeploymentPrerequisitesRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.DeploymentPrerequisites.FromString,
                _registered_method=True)


class GatewayServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetOAuthArguments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount(self, request, context):
        """CRUD APIs for Accounts

        Create Account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Get Account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccounts(self, request, context):
        """List Accounts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount(self, request, context):
        """Update Account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPaymentMethods(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCosts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInvoices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportBillingMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTotalHistoricalSpend(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBatchJob(self, request, context):
        """CRUD APIs for batch jobs.

        Create Batch Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJob(self, request, context):
        """Get Batch Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchJobs(self, request, context):
        """List Batch Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBatchJob(self, request, context):
        """Update Batch Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBatchJob(self, request, context):
        """Delete Batch Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDeleteBatchJobs(self, request, context):
        """Batch Delete Batch Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBatchJob(self, request, context):
        """Cancel Batch Job

        Cancels an existing batch job if it is queued, pending, or running.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCluster(self, request, context):
        """CRUD APIs for clusters.

        Create Cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCluster(self, request, context):
        """Get Cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClusters(self, request, context):
        """List Clusters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCluster(self, request, context):
        """Update Cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCluster(self, request, context):
        """Delete Cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterConnectionInfo(self, request, context):
        """Get Cluster Connection Info

        Retrieve connection settings for the cluster to be put in kubeconfig
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEnvironment(self, request, context):
        """CRUD APIs for environments.

        Create Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """Get Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironments(self, request, context):
        """List Environments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironment(self, request, context):
        """Update Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironment(self, request, context):
        """Delete Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDeleteEnvironments(self, request, context):
        """Batch Delete Environments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectEnvironment(self, request, context):
        """Connect Environment

        Connects the environment to a node pool.
        Returns an error if there is an existing pending connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectEnvironment(self, request, context):
        """Disconnect Environment

        Disconnects the environment from the node pool. Returns an error
        if the environment is not connected to a node pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureFlag(self, request, context):
        """CRUD APIs for account feature flags.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureFlags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSnapshot(self, request, context):
        """CRUD APIs for snapshots.

        Create Snapshot
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSnapshot(self, request, context):
        """Get Snapshot
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSnapshots(self, request, context):
        """List Snapshots
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSnapshot(self, request, context):
        """Delete Snapshot
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobLogs(self, request, context):
        """Get Batch Job Logs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNodePool(self, request, context):
        """CRUD APIs for node pools.

        Create Node Pool
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodePool(self, request, context):
        """Get Node Pool
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodePools(self, request, context):
        """List Node Pools
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNodePool(self, request, context):
        """Update Node Pool
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNodePool(self, request, context):
        """Delete Node Pool
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDeleteNodePools(self, request, context):
        """Batch Delete Node Pools
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodePoolStats(self, request, context):
        """Get Node Pool Stats
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """CRUD APIs for users.

        Create User
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get User
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """List Users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """Update User
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAuditLogs(self, request, context):
        """List User Audit Logs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiKey(self, request, context):
        """CRUD APIs for API keys.

        Create API Key
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApiKeys(self, request, context):
        """List API Keys
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteApiKey(self, request, context):
        """Delete API Key
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInternalApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModel(self, request, context):
        """CRUD APIs for models.

        Create Model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModel(self, request, context):
        """Get Model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """List Models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListServerlessLoraModels(self, request, context):
        """List Serverless Lora Models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModel(self, request, context):
        """Update Model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModel(self, request, context):
        """Delete Model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelUploadEndpoint(self, request, context):
        """Get Model Upload Endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDownloadEndpoint(self, request, context):
        """Get Model Download Endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateModelUpload(self, request, context):
        """Validate Model Upload
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateModelConfig(self, request, context):
        """Validate Model Config
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportModel(self, request, context):
        """Transfer model from S3 to GCP storage
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDeployment(self, request, context):
        """CRUD APIs for deployments.

        Create Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeployment(self, request, context):
        """Get Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeployments(self, request, context):
        """List Deployments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeployment(self, request, context):
        """Update Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDeployment(self, request, context):
        """Delete Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeleteDeployment(self, request, context):
        """Undelete Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScaleDeployment(self, request, context):
        """Scale Deployment to a specific number of replicas or to zero
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentMetrics(self, request, context):
        """Get Deployment Metrics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDeploymentTemplate(self, request, context):
        """CRUD APIs for deployment templates.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeploymentTemplates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeploymentTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDeploymentTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDeployedModel(self, request, context):
        """CRUD APIs for deployed models.

        Load LoRA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeployedModel(self, request, context):
        """Get LoRA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeployedModels(self, request, context):
        """List LoRAs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeployedModel(self, request, context):
        """Update LoRA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDeployedModel(self, request, context):
        """Unload LoRA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAwsIamRoleBinding(self, request, context):
        """CRUD APIs for AWS IAM role bindings.

        Create Aws Iam Role Binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAwsIamRoleBindings(self, request, context):
        """List Aws Iam Role Bindings
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAwsIamRoleBinding(self, request, context):
        """Delete Aws Iam Role Binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNodePoolBinding(self, request, context):
        """CRUD APIs for node pool bindings.

        Create Node Pool Binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodePoolBindings(self, request, context):
        """List Node Pool Bindings
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNodePoolBinding(self, request, context):
        """Delete Node Pool Binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataset(self, request, context):
        """CRUD APIs for datasets.

        Create Dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataset(self, request, context):
        """Get Dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatasets(self, request, context):
        """List Datasets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataset(self, request, context):
        """Update Dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataset(self, request, context):
        """Delete Dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadDataset(self, request, context):
        """Upload and verify files for datasets.

        Upload Dataset (Deprecated)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetUploadEndpoint(self, request, context):
        """Get Dataset Upload Endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDatasetUpload(self, request, context):
        """Validate Dataset Upload
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetDownloadEndpoint(self, request, context):
        """Get Dataset Download Endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewDataset(self, request, context):
        """Preview Dataset, will contain the content of the dataset row by row
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEvaluator(self, request, context):
        """CRUD APIs for evaluations.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvaluator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvaluators(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEvaluator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEvaluation(self, request, context):
        """Create Evaluation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvaluation(self, request, context):
        """Get Evaluation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvaluations(self, request, context):
        """List Evaluations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEvaluation(self, request, context):
        """TODO: Add Update Evaluation
        Update Evaluation
        rpc UpdateEvaluation(UpdateEvaluationRequest) returns (Evaluation) {
        option (google.api.http) = {
        patch: "/v1/{evaluation.name=accounts/*/evaluations/*}"
        body: "evaluation"
        };
        }
        Delete Evaluation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEvaluationJob(self, request, context):
        """CRUD APIs for evaluation jobs.

        Create Evaluation Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvaluationJob(self, request, context):
        """Get Evaluation Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvaluationJobs(self, request, context):
        """List Evaluation Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEvaluationJob(self, request, context):
        """Delete Evaluation Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFineTuningJob(self, request, context):
        """CRUD APIs for fine-tune jobs.

        Create Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFineTuningJob(self, request, context):
        """Get Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFineTuningJobs(self, request, context):
        """List Fine-tuning Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFineTuningJob(self, request, context):
        """Update Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFineTuningJob(self, request, context):
        """Delete Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSupervisedFineTuningJob(self, request, context):
        """CRUD APIs for supervised fine-tune jobs.

        Create Supervised Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSupervisedFineTuningJob(self, request, context):
        """Get Supervised Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSupervisedFineTuningJobs(self, request, context):
        """List Supervised Fine-tuning Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSupervisedFineTuningJob(self, request, context):
        """Delete Supervised Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateReinforcementFineTuningJob(self, request, context):
        """CRUD APIs for reinforcement learning fine-tune jobs.

        Create Reinforcement Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReinforcementFineTuningJob(self, request, context):
        """Get Reinforcement Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReinforcementFineTuningJobs(self, request, context):
        """List Reinforcement Fine-tuning Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteReinforcementFineTuningJob(self, request, context):
        """Delete Reinforcement Fine-tuning Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateReinforcementFineTuningEpoch(self, request, context):
        """CRUD APIs for reinforcement learning fine-tuning epochs.

        Create Reinforcement Fine-tuning Epoch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReinforcementFineTuningEpoch(self, request, context):
        """Get Reinforcement Fine-tuning Epoch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReinforcementFineTuningEpochs(self, request, context):
        """List Reinforcement Fine-tuning Epochs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteReinforcementFineTuningEpoch(self, request, context):
        """Delete Reinforcement Fine-tuning Epoch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRlorTrainerJob(self, request, context):
        """CRUD APIs for rlor trainer jobs.

        Create Rlor Trainer Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRlorTrainerJob(self, request, context):
        """Get Rlor Trainer Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRlorTrainerJobs(self, request, context):
        """List Rlor Trainer Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRlorTrainerJob(self, request, context):
        """Delete Rlor Trainer Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePeftMergeJob(self, request, context):
        """CRUD APIs for peft merge jobs.

        Create Peft-Merge Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPeftMergeJob(self, request, context):
        """Get Peft-Merge Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPeftMergeJobs(self, request, context):
        """List Peft-Merge Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePeftMergeJob(self, request, context):
        """Delete Peft-Merge Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQuota(self, request, context):
        """CRUD APIs for quotas.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateQuota(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListQuotas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSecrets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReservation(self, request, context):
        """CRUD APIs for reservations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReservations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareModel(self, request, context):
        """Prepare Model for different precisions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBatchInferenceJob(self, request, context):
        """CRUD APIs for batch inference jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchInferenceJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchInferenceJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBatchInferenceJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBatchInferenceJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEagleTrainingJob(self, request, context):
        """CRUD APIs for EAGLE training jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEagleTrainingJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEagleTrainingJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEagleTrainingJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchInferenceJobInputUploadEndpoint(self, request, context):
        """Upload, download and verify files for batch inference jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchInferenceJobOutputDownloadEndpoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateBatchInferenceJobInputUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDatasetValidationJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetValidationJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatasetValidationJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatasetValidationJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateAssertions(self, request, context):
        """Validate evaluation assertions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewEvaluator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewEvaluation(self, request, context):
        """Preview an evaluation with sample data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestEvaluation(self, request, context):
        """Similar to preview evaluation, but no need to create the evaluation entry first.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInferenceLog(self, request, context):
        """CRUD APIs for inference logs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInferenceLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInferenceLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentPrerequisites(self, request, context):
        """GetDeploymentPrerequisites returns the validation criteria for creating a particular deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GatewayServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetOAuthArguments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOAuthArguments,
                    request_deserializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsRequest.FromString,
                    response_serializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsResponse.SerializeToString,
            ),
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=gateway_dot_account__pb2.CreateAccountRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.Account.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=gateway_dot_account__pb2.GetAccountRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.Account.SerializeToString,
            ),
            'ListAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccounts,
                    request_deserializer=gateway_dot_account__pb2.ListAccountsRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.ListAccountsResponse.SerializeToString,
            ),
            'UpdateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount,
                    request_deserializer=gateway_dot_account__pb2.UpdateAccountRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.Account.SerializeToString,
            ),
            'DeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccount,
                    request_deserializer=gateway_dot_account__pb2.DeleteAccountRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBalance,
                    request_deserializer=gateway_dot_billing__pb2.GetBalanceRequest.FromString,
                    response_serializer=gateway_dot_billing__pb2.Balance.SerializeToString,
            ),
            'ListPaymentMethods': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPaymentMethods,
                    request_deserializer=gateway_dot_billing__pb2.ListPaymentMethodsRequest.FromString,
                    response_serializer=gateway_dot_billing__pb2.ListPaymentMethodsResponse.SerializeToString,
            ),
            'ListCosts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCosts,
                    request_deserializer=gateway_dot_billing__pb2.ListCostsRequest.FromString,
                    response_serializer=gateway_dot_billing__pb2.ListCostsResponse.SerializeToString,
            ),
            'ListInvoices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInvoices,
                    request_deserializer=gateway_dot_billing__pb2.ListInvoicesRequest.FromString,
                    response_serializer=gateway_dot_billing__pb2.ListInvoicesResponse.SerializeToString,
            ),
            'ExportBillingMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportBillingMetrics,
                    request_deserializer=gateway_dot_billing__pb2.ExportBillingMetricsRequest.FromString,
                    response_serializer=gateway_dot_billing__pb2.ExportBillingMetricsResponse.SerializeToString,
            ),
            'GetTotalHistoricalSpend': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTotalHistoricalSpend,
                    request_deserializer=gateway_dot_billing__pb2.GetTotalHistoricalSpendRequest.FromString,
                    response_serializer=gateway_dot_billing__pb2.GetTotalHistoricalSpendResponse.SerializeToString,
            ),
            'CreateBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.CreateBatchJobRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.BatchJob.SerializeToString,
            ),
            'GetBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.GetBatchJobRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.BatchJob.SerializeToString,
            ),
            'ListBatchJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchJobs,
                    request_deserializer=gateway_dot_batch__job__pb2.ListBatchJobsRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.ListBatchJobsResponse.SerializeToString,
            ),
            'UpdateBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.UpdateBatchJobRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.BatchJob.SerializeToString,
            ),
            'DeleteBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.DeleteBatchJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchDeleteBatchJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDeleteBatchJobs,
                    request_deserializer=gateway_dot_batch__job__pb2.BatchDeleteBatchJobsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CancelBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.CancelBatchJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCluster,
                    request_deserializer=gateway_dot_cluster__pb2.CreateClusterRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'GetCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCluster,
                    request_deserializer=gateway_dot_cluster__pb2.GetClusterRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'ListClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClusters,
                    request_deserializer=gateway_dot_cluster__pb2.ListClustersRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.ListClustersResponse.SerializeToString,
            ),
            'UpdateCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCluster,
                    request_deserializer=gateway_dot_cluster__pb2.UpdateClusterRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'DeleteCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCluster,
                    request_deserializer=gateway_dot_cluster__pb2.DeleteClusterRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetClusterConnectionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterConnectionInfo,
                    request_deserializer=gateway_dot_cluster__pb2.GetClusterConnectionInfoRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.ClusterConnectionInfo.SerializeToString,
            ),
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.Environment.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.Environment.SerializeToString,
            ),
            'ListEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironments,
                    request_deserializer=gateway_dot_environment__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'UpdateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.UpdateEnvironmentRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.Environment.SerializeToString,
            ),
            'DeleteEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.DeleteEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchDeleteEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDeleteEnvironments,
                    request_deserializer=gateway_dot_environment__pb2.BatchDeleteEnvironmentsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ConnectEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.ConnectEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisconnectEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.DisconnectEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetFeatureFlag': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureFlag,
                    request_deserializer=gateway_dot_feature__flag__pb2.GetFeatureFlagRequest.FromString,
                    response_serializer=gateway_dot_feature__flag__pb2.FeatureFlag.SerializeToString,
            ),
            'ListFeatureFlags': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureFlags,
                    request_deserializer=gateway_dot_feature__flag__pb2.ListFeatureFlagsRequest.FromString,
                    response_serializer=gateway_dot_feature__flag__pb2.ListFeatureFlagsResponse.SerializeToString,
            ),
            'CreateSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSnapshot,
                    request_deserializer=gateway_dot_snapshot__pb2.CreateSnapshotRequest.FromString,
                    response_serializer=gateway_dot_snapshot__pb2.Snapshot.SerializeToString,
            ),
            'GetSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSnapshot,
                    request_deserializer=gateway_dot_snapshot__pb2.GetSnapshotRequest.FromString,
                    response_serializer=gateway_dot_snapshot__pb2.Snapshot.SerializeToString,
            ),
            'ListSnapshots': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSnapshots,
                    request_deserializer=gateway_dot_snapshot__pb2.ListSnapshotsRequest.FromString,
                    response_serializer=gateway_dot_snapshot__pb2.ListSnapshotsResponse.SerializeToString,
            ),
            'DeleteSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSnapshot,
                    request_deserializer=gateway_dot_snapshot__pb2.DeleteSnapshotRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetBatchJobLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobLogs,
                    request_deserializer=gateway_dot_batch__job__pb2.GetBatchJobLogsRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.GetBatchJobLogsResponse.SerializeToString,
            ),
            'CreateNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.CreateNodePoolRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePool.SerializeToString,
            ),
            'GetNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.GetNodePoolRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePool.SerializeToString,
            ),
            'ListNodePools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodePools,
                    request_deserializer=gateway_dot_node__pool__pb2.ListNodePoolsRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.ListNodePoolsResponse.SerializeToString,
            ),
            'UpdateNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.UpdateNodePoolRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePool.SerializeToString,
            ),
            'DeleteNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.DeleteNodePoolRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchDeleteNodePools': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDeleteNodePools,
                    request_deserializer=gateway_dot_node__pool__pb2.BatchDeleteNodePoolsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetNodePoolStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodePoolStats,
                    request_deserializer=gateway_dot_node__pool__pb2.GetNodePoolStatsRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePoolStats.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=gateway_dot_user__pb2.CreateUserRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.User.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=gateway_dot_user__pb2.GetUserRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.User.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=gateway_dot_user__pb2.ListUsersRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.ListUsersResponse.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=gateway_dot_user__pb2.UpdateUserRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.User.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=gateway_dot_user__pb2.DeleteUserRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListAuditLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAuditLogs,
                    request_deserializer=gateway_dot_audit__log__pb2.ListAuditLogsRequest.FromString,
                    response_serializer=gateway_dot_audit__log__pb2.ListAuditLogsResponse.SerializeToString,
            ),
            'CreateApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiKey,
                    request_deserializer=gateway_dot_api__key__pb2.CreateApiKeyRequest.FromString,
                    response_serializer=gateway_dot_api__key__pb2.ApiKey.SerializeToString,
            ),
            'ListApiKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApiKeys,
                    request_deserializer=gateway_dot_api__key__pb2.ListApiKeysRequest.FromString,
                    response_serializer=gateway_dot_api__key__pb2.ListApiKeysResponse.SerializeToString,
            ),
            'DeleteApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteApiKey,
                    request_deserializer=gateway_dot_api__key__pb2.DeleteApiKeyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetInternalApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInternalApiKey,
                    request_deserializer=gateway_dot_api__key__pb2.GetInternalApiKeyRequest.FromString,
                    response_serializer=gateway_dot_api__key__pb2.ApiKey.SerializeToString,
            ),
            'CreateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModel,
                    request_deserializer=gateway_dot_model__pb2.CreateModelRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.Model.SerializeToString,
            ),
            'GetModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModel,
                    request_deserializer=gateway_dot_model__pb2.GetModelRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.Model.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=gateway_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'ListServerlessLoraModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListServerlessLoraModels,
                    request_deserializer=gateway_dot_model__pb2.ListServerlessLoraModelsRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.ListServerlessLoraModelsResponse.SerializeToString,
            ),
            'UpdateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModel,
                    request_deserializer=gateway_dot_model__pb2.UpdateModelRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.Model.SerializeToString,
            ),
            'DeleteModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModel,
                    request_deserializer=gateway_dot_model__pb2.DeleteModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetModelUploadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelUploadEndpoint,
                    request_deserializer=gateway_dot_model__pb2.GetModelUploadEndpointRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.GetModelUploadEndpointResponse.SerializeToString,
            ),
            'GetModelDownloadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDownloadEndpoint,
                    request_deserializer=gateway_dot_model__pb2.GetModelDownloadEndpointRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.GetModelDownloadEndpointResponse.SerializeToString,
            ),
            'ValidateModelUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateModelUpload,
                    request_deserializer=gateway_dot_model__pb2.ValidateModelUploadRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ValidateModelConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateModelConfig,
                    request_deserializer=gateway_dot_model__pb2.ValidateModelConfigRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ImportModel': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportModel,
                    request_deserializer=gateway_dot_model__pb2.ImportModelRequest.FromString,
                    response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
            ),
            'CreateDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.CreateDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'GetDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.GetDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'ListDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeployments,
                    request_deserializer=gateway_dot_deployment__pb2.ListDeploymentsRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.ListDeploymentsResponse.SerializeToString,
            ),
            'UpdateDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.UpdateDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'DeleteDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.DeleteDeploymentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UndeleteDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeleteDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.UndeleteDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'ScaleDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.ScaleDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.ScaleDeploymentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetDeploymentMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentMetrics,
                    request_deserializer=gateway_dot_deployment__pb2.GetDeploymentMetricsRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.GetDeploymentMetricsResponse.SerializeToString,
            ),
            'CreateDeploymentTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDeploymentTemplate,
                    request_deserializer=gateway_dot_deployment__template__pb2.CreateDeploymentTemplateRequest.FromString,
                    response_serializer=gateway_dot_deployment__template__pb2.DeploymentTemplate.SerializeToString,
            ),
            'GetDeploymentTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentTemplate,
                    request_deserializer=gateway_dot_deployment__template__pb2.GetDeploymentTemplateRequest.FromString,
                    response_serializer=gateway_dot_deployment__template__pb2.DeploymentTemplate.SerializeToString,
            ),
            'ListDeploymentTemplates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeploymentTemplates,
                    request_deserializer=gateway_dot_deployment__template__pb2.ListDeploymentTemplatesRequest.FromString,
                    response_serializer=gateway_dot_deployment__template__pb2.ListDeploymentTemplatesResponse.SerializeToString,
            ),
            'UpdateDeploymentTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeploymentTemplate,
                    request_deserializer=gateway_dot_deployment__template__pb2.UpdateDeploymentTemplateRequest.FromString,
                    response_serializer=gateway_dot_deployment__template__pb2.DeploymentTemplate.SerializeToString,
            ),
            'DeleteDeploymentTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDeploymentTemplate,
                    request_deserializer=gateway_dot_deployment__template__pb2.DeleteDeploymentTemplateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateDeployedModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDeployedModel,
                    request_deserializer=gateway_dot_deployed__model__pb2.CreateDeployedModelRequest.FromString,
                    response_serializer=gateway_dot_deployed__model__pb2.DeployedModel.SerializeToString,
            ),
            'GetDeployedModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeployedModel,
                    request_deserializer=gateway_dot_deployed__model__pb2.GetDeployedModelRequest.FromString,
                    response_serializer=gateway_dot_deployed__model__pb2.DeployedModel.SerializeToString,
            ),
            'ListDeployedModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeployedModels,
                    request_deserializer=gateway_dot_deployed__model__pb2.ListDeployedModelsRequest.FromString,
                    response_serializer=gateway_dot_deployed__model__pb2.ListDeployedModelsResponse.SerializeToString,
            ),
            'UpdateDeployedModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeployedModel,
                    request_deserializer=gateway_dot_deployed__model__pb2.UpdateDeployedModelRequest.FromString,
                    response_serializer=gateway_dot_deployed__model__pb2.DeployedModel.SerializeToString,
            ),
            'DeleteDeployedModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDeployedModel,
                    request_deserializer=gateway_dot_deployed__model__pb2.DeleteDeployedModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateAwsIamRoleBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAwsIamRoleBinding,
                    request_deserializer=gateway_dot_aws__iam__role__binding__pb2.CreateAwsIamRoleBindingRequest.FromString,
                    response_serializer=gateway_dot_aws__iam__role__binding__pb2.AwsIamRoleBinding.SerializeToString,
            ),
            'ListAwsIamRoleBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAwsIamRoleBindings,
                    request_deserializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsRequest.FromString,
                    response_serializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsResponse.SerializeToString,
            ),
            'DeleteAwsIamRoleBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAwsIamRoleBinding,
                    request_deserializer=gateway_dot_aws__iam__role__binding__pb2.DeleteAwsIamRoleBindingRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateNodePoolBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNodePoolBinding,
                    request_deserializer=gateway_dot_node__pool__binding__pb2.CreateNodePoolBindingRequest.FromString,
                    response_serializer=gateway_dot_node__pool__binding__pb2.NodePoolBinding.SerializeToString,
            ),
            'ListNodePoolBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodePoolBindings,
                    request_deserializer=gateway_dot_node__pool__binding__pb2.ListNodePoolBindingsRequest.FromString,
                    response_serializer=gateway_dot_node__pool__binding__pb2.ListNodePoolBindingsResponse.SerializeToString,
            ),
            'DeleteNodePoolBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNodePoolBinding,
                    request_deserializer=gateway_dot_node__pool__binding__pb2.DeleteNodePoolBindingRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataset,
                    request_deserializer=gateway_dot_dataset__pb2.CreateDatasetRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.Dataset.SerializeToString,
            ),
            'GetDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataset,
                    request_deserializer=gateway_dot_dataset__pb2.GetDatasetRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.Dataset.SerializeToString,
            ),
            'ListDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDatasets,
                    request_deserializer=gateway_dot_dataset__pb2.ListDatasetsRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.ListDatasetsResponse.SerializeToString,
            ),
            'UpdateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataset,
                    request_deserializer=gateway_dot_dataset__pb2.UpdateDatasetRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.Dataset.SerializeToString,
            ),
            'DeleteDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataset,
                    request_deserializer=gateway_dot_dataset__pb2.DeleteDatasetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UploadDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadDataset,
                    request_deserializer=gateway_dot_dataset__pb2.UploadDatasetRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.UploadDatasetResponse.SerializeToString,
            ),
            'GetDatasetUploadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetUploadEndpoint,
                    request_deserializer=gateway_dot_dataset__pb2.GetDatasetUploadEndpointRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.GetDatasetUploadEndpointResponse.SerializeToString,
            ),
            'ValidateDatasetUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDatasetUpload,
                    request_deserializer=gateway_dot_dataset__pb2.ValidateDatasetUploadRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetDatasetDownloadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetDownloadEndpoint,
                    request_deserializer=gateway_dot_dataset__pb2.GetDatasetDownloadEndpointRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.GetDatasetDownloadEndpointResponse.SerializeToString,
            ),
            'PreviewDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewDataset,
                    request_deserializer=gateway_dot_dataset__pb2.PreviewDatasetRequest.FromString,
                    response_serializer=gateway_dot_dataset__pb2.PreviewDatasetResponse.SerializeToString,
            ),
            'CreateEvaluator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvaluator,
                    request_deserializer=gateway_dot_evaluator__pb2.CreateEvaluatorRequest.FromString,
                    response_serializer=gateway_dot_evaluator__pb2.Evaluator.SerializeToString,
            ),
            'GetEvaluator': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvaluator,
                    request_deserializer=gateway_dot_evaluator__pb2.GetEvaluatorRequest.FromString,
                    response_serializer=gateway_dot_evaluator__pb2.Evaluator.SerializeToString,
            ),
            'ListEvaluators': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvaluators,
                    request_deserializer=gateway_dot_evaluator__pb2.ListEvaluatorsRequest.FromString,
                    response_serializer=gateway_dot_evaluator__pb2.ListEvaluatorsResponse.SerializeToString,
            ),
            'DeleteEvaluator': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEvaluator,
                    request_deserializer=gateway_dot_evaluator__pb2.DeleteEvaluatorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEvaluation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvaluation,
                    request_deserializer=gateway_dot_evaluation__pb2.CreateEvaluationRequest.FromString,
                    response_serializer=gateway_dot_evaluation__pb2.Evaluation.SerializeToString,
            ),
            'GetEvaluation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvaluation,
                    request_deserializer=gateway_dot_evaluation__pb2.GetEvaluationRequest.FromString,
                    response_serializer=gateway_dot_evaluation__pb2.Evaluation.SerializeToString,
            ),
            'ListEvaluations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvaluations,
                    request_deserializer=gateway_dot_evaluation__pb2.ListEvaluationsRequest.FromString,
                    response_serializer=gateway_dot_evaluation__pb2.ListEvaluationsResponse.SerializeToString,
            ),
            'DeleteEvaluation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEvaluation,
                    request_deserializer=gateway_dot_evaluation__pb2.DeleteEvaluationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEvaluationJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvaluationJob,
                    request_deserializer=gateway_dot_evaluation__job__pb2.CreateEvaluationJobRequest.FromString,
                    response_serializer=gateway_dot_evaluation__job__pb2.EvaluationJob.SerializeToString,
            ),
            'GetEvaluationJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvaluationJob,
                    request_deserializer=gateway_dot_evaluation__job__pb2.GetEvaluationJobRequest.FromString,
                    response_serializer=gateway_dot_evaluation__job__pb2.EvaluationJob.SerializeToString,
            ),
            'ListEvaluationJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvaluationJobs,
                    request_deserializer=gateway_dot_evaluation__job__pb2.ListEvaluationJobsRequest.FromString,
                    response_serializer=gateway_dot_evaluation__job__pb2.ListEvaluationJobsResponse.SerializeToString,
            ),
            'DeleteEvaluationJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEvaluationJob,
                    request_deserializer=gateway_dot_evaluation__job__pb2.DeleteEvaluationJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFineTuningJob,
                    request_deserializer=gateway_dot_fine__tuning__job__pb2.CreateFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_fine__tuning__job__pb2.FineTuningJob.SerializeToString,
            ),
            'GetFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFineTuningJob,
                    request_deserializer=gateway_dot_fine__tuning__job__pb2.GetFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_fine__tuning__job__pb2.FineTuningJob.SerializeToString,
            ),
            'ListFineTuningJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFineTuningJobs,
                    request_deserializer=gateway_dot_fine__tuning__job__pb2.ListFineTuningJobsRequest.FromString,
                    response_serializer=gateway_dot_fine__tuning__job__pb2.ListFineTuningJobsResponse.SerializeToString,
            ),
            'UpdateFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFineTuningJob,
                    request_deserializer=gateway_dot_fine__tuning__job__pb2.UpdateFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_fine__tuning__job__pb2.FineTuningJob.SerializeToString,
            ),
            'DeleteFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFineTuningJob,
                    request_deserializer=gateway_dot_fine__tuning__job__pb2.DeleteFineTuningJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateSupervisedFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSupervisedFineTuningJob,
                    request_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.CreateSupervisedFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_supervised__fine__tuning__job__pb2.SupervisedFineTuningJob.SerializeToString,
            ),
            'GetSupervisedFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSupervisedFineTuningJob,
                    request_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.GetSupervisedFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_supervised__fine__tuning__job__pb2.SupervisedFineTuningJob.SerializeToString,
            ),
            'ListSupervisedFineTuningJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSupervisedFineTuningJobs,
                    request_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.ListSupervisedFineTuningJobsRequest.FromString,
                    response_serializer=gateway_dot_supervised__fine__tuning__job__pb2.ListSupervisedFineTuningJobsResponse.SerializeToString,
            ),
            'DeleteSupervisedFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSupervisedFineTuningJob,
                    request_deserializer=gateway_dot_supervised__fine__tuning__job__pb2.DeleteSupervisedFineTuningJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateReinforcementFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateReinforcementFineTuningJob,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.CreateReinforcementFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ReinforcementFineTuningJob.SerializeToString,
            ),
            'GetReinforcementFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReinforcementFineTuningJob,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.GetReinforcementFineTuningJobRequest.FromString,
                    response_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ReinforcementFineTuningJob.SerializeToString,
            ),
            'ListReinforcementFineTuningJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReinforcementFineTuningJobs,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ListReinforcementFineTuningJobsRequest.FromString,
                    response_serializer=gateway_dot_reinforcement__fine__tuning__job__pb2.ListReinforcementFineTuningJobsResponse.SerializeToString,
            ),
            'DeleteReinforcementFineTuningJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteReinforcementFineTuningJob,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__job__pb2.DeleteReinforcementFineTuningJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateReinforcementFineTuningEpoch': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateReinforcementFineTuningEpoch,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.CreateReinforcementFineTuningEpochRequest.FromString,
                    response_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ReinforcementFineTuningEpoch.SerializeToString,
            ),
            'GetReinforcementFineTuningEpoch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReinforcementFineTuningEpoch,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.GetReinforcementFineTuningEpochRequest.FromString,
                    response_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ReinforcementFineTuningEpoch.SerializeToString,
            ),
            'ListReinforcementFineTuningEpochs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReinforcementFineTuningEpochs,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ListReinforcementFineTuningEpochsRequest.FromString,
                    response_serializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.ListReinforcementFineTuningEpochsResponse.SerializeToString,
            ),
            'DeleteReinforcementFineTuningEpoch': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteReinforcementFineTuningEpoch,
                    request_deserializer=gateway_dot_reinforcement__fine__tuning__epoch__pb2.DeleteReinforcementFineTuningEpochRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateRlorTrainerJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRlorTrainerJob,
                    request_deserializer=gateway_dot_rlor__trainer__job__pb2.CreateRlorTrainerJobRequest.FromString,
                    response_serializer=gateway_dot_rlor__trainer__job__pb2.RlorTrainerJob.SerializeToString,
            ),
            'GetRlorTrainerJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRlorTrainerJob,
                    request_deserializer=gateway_dot_rlor__trainer__job__pb2.GetRlorTrainerJobRequest.FromString,
                    response_serializer=gateway_dot_rlor__trainer__job__pb2.RlorTrainerJob.SerializeToString,
            ),
            'ListRlorTrainerJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRlorTrainerJobs,
                    request_deserializer=gateway_dot_rlor__trainer__job__pb2.ListRlorTrainerJobsRequest.FromString,
                    response_serializer=gateway_dot_rlor__trainer__job__pb2.ListRlorTrainerJobsResponse.SerializeToString,
            ),
            'DeleteRlorTrainerJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRlorTrainerJob,
                    request_deserializer=gateway_dot_rlor__trainer__job__pb2.DeleteRlorTrainerJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreatePeftMergeJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePeftMergeJob,
                    request_deserializer=gateway_dot_peft__merge__job__pb2.CreatePeftMergeJobRequest.FromString,
                    response_serializer=gateway_dot_peft__merge__job__pb2.PeftMergeJob.SerializeToString,
            ),
            'GetPeftMergeJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPeftMergeJob,
                    request_deserializer=gateway_dot_peft__merge__job__pb2.GetPeftMergeJobRequest.FromString,
                    response_serializer=gateway_dot_peft__merge__job__pb2.PeftMergeJob.SerializeToString,
            ),
            'ListPeftMergeJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPeftMergeJobs,
                    request_deserializer=gateway_dot_peft__merge__job__pb2.ListPeftMergeJobsRequest.FromString,
                    response_serializer=gateway_dot_peft__merge__job__pb2.ListPeftMergeJobsResponse.SerializeToString,
            ),
            'DeletePeftMergeJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePeftMergeJob,
                    request_deserializer=gateway_dot_peft__merge__job__pb2.DeletePeftMergeJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetQuota': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQuota,
                    request_deserializer=gateway_dot_quota__pb2.GetQuotaRequest.FromString,
                    response_serializer=gateway_dot_quota__pb2.Quota.SerializeToString,
            ),
            'UpdateQuota': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateQuota,
                    request_deserializer=gateway_dot_quota__pb2.UpdateQuotaRequest.FromString,
                    response_serializer=gateway_dot_quota__pb2.Quota.SerializeToString,
            ),
            'ListQuotas': grpc.unary_unary_rpc_method_handler(
                    servicer.ListQuotas,
                    request_deserializer=gateway_dot_quota__pb2.ListQuotasRequest.FromString,
                    response_serializer=gateway_dot_quota__pb2.ListQuotasResponse.SerializeToString,
            ),
            'CreateSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSecret,
                    request_deserializer=gateway_dot_secret__pb2.CreateSecretRequest.FromString,
                    response_serializer=gateway_dot_secret__pb2.Secret.SerializeToString,
            ),
            'GetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecret,
                    request_deserializer=gateway_dot_secret__pb2.GetSecretRequest.FromString,
                    response_serializer=gateway_dot_secret__pb2.Secret.SerializeToString,
            ),
            'ListSecrets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSecrets,
                    request_deserializer=gateway_dot_secret__pb2.ListSecretsRequest.FromString,
                    response_serializer=gateway_dot_secret__pb2.ListSecretsResponse.SerializeToString,
            ),
            'UpdateSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSecret,
                    request_deserializer=gateway_dot_secret__pb2.UpdateSecretRequest.FromString,
                    response_serializer=gateway_dot_secret__pb2.Secret.SerializeToString,
            ),
            'DeleteSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSecret,
                    request_deserializer=gateway_dot_secret__pb2.DeleteSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetReservation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReservation,
                    request_deserializer=gateway_dot_reservation__pb2.GetReservationRequest.FromString,
                    response_serializer=gateway_dot_reservation__pb2.Reservation.SerializeToString,
            ),
            'ListReservations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReservations,
                    request_deserializer=gateway_dot_reservation__pb2.ListReservationsRequest.FromString,
                    response_serializer=gateway_dot_reservation__pb2.ListReservationsResponse.SerializeToString,
            ),
            'PrepareModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareModel,
                    request_deserializer=gateway_dot_model__pb2.PrepareModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateBatchInferenceJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBatchInferenceJob,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.CreateBatchInferenceJobRequest.FromString,
                    response_serializer=gateway_dot_batch__inference__job__pb2.BatchInferenceJob.SerializeToString,
            ),
            'GetBatchInferenceJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchInferenceJob,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobRequest.FromString,
                    response_serializer=gateway_dot_batch__inference__job__pb2.BatchInferenceJob.SerializeToString,
            ),
            'ListBatchInferenceJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchInferenceJobs,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.ListBatchInferenceJobsRequest.FromString,
                    response_serializer=gateway_dot_batch__inference__job__pb2.ListBatchInferenceJobsResponse.SerializeToString,
            ),
            'UpdateBatchInferenceJob': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBatchInferenceJob,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.UpdateBatchInferenceJobRequest.FromString,
                    response_serializer=gateway_dot_batch__inference__job__pb2.BatchInferenceJob.SerializeToString,
            ),
            'DeleteBatchInferenceJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBatchInferenceJob,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.DeleteBatchInferenceJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEagleTrainingJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEagleTrainingJob,
                    request_deserializer=gateway_dot_eagle__training__job__pb2.CreateEagleTrainingJobRequest.FromString,
                    response_serializer=gateway_dot_eagle__training__job__pb2.EagleTrainingJob.SerializeToString,
            ),
            'GetEagleTrainingJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEagleTrainingJob,
                    request_deserializer=gateway_dot_eagle__training__job__pb2.GetEagleTrainingJobRequest.FromString,
                    response_serializer=gateway_dot_eagle__training__job__pb2.EagleTrainingJob.SerializeToString,
            ),
            'ListEagleTrainingJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEagleTrainingJobs,
                    request_deserializer=gateway_dot_eagle__training__job__pb2.ListEagleTrainingJobsRequest.FromString,
                    response_serializer=gateway_dot_eagle__training__job__pb2.ListEagleTrainingJobsResponse.SerializeToString,
            ),
            'DeleteEagleTrainingJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEagleTrainingJob,
                    request_deserializer=gateway_dot_eagle__training__job__pb2.DeleteEagleTrainingJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetBatchInferenceJobInputUploadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchInferenceJobInputUploadEndpoint,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobInputUploadEndpointRequest.FromString,
                    response_serializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobInputUploadEndpointResponse.SerializeToString,
            ),
            'GetBatchInferenceJobOutputDownloadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchInferenceJobOutputDownloadEndpoint,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobOutputDownloadEndpointRequest.FromString,
                    response_serializer=gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobOutputDownloadEndpointResponse.SerializeToString,
            ),
            'ValidateBatchInferenceJobInputUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateBatchInferenceJobInputUpload,
                    request_deserializer=gateway_dot_batch__inference__job__pb2.ValidateBatchInferenceJobInputUploadRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateDatasetValidationJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasetValidationJob,
                    request_deserializer=gateway_dot_dataset__validation__job__pb2.CreateDatasetValidationJobRequest.FromString,
                    response_serializer=gateway_dot_dataset__validation__job__pb2.DatasetValidationJob.SerializeToString,
            ),
            'GetDatasetValidationJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetValidationJob,
                    request_deserializer=gateway_dot_dataset__validation__job__pb2.GetDatasetValidationJobRequest.FromString,
                    response_serializer=gateway_dot_dataset__validation__job__pb2.DatasetValidationJob.SerializeToString,
            ),
            'ListDatasetValidationJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDatasetValidationJobs,
                    request_deserializer=gateway_dot_dataset__validation__job__pb2.ListDatasetValidationJobsRequest.FromString,
                    response_serializer=gateway_dot_dataset__validation__job__pb2.ListDatasetValidationJobsResponse.SerializeToString,
            ),
            'DeleteDatasetValidationJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatasetValidationJob,
                    request_deserializer=gateway_dot_dataset__validation__job__pb2.DeleteDatasetValidationJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ValidateAssertions': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateAssertions,
                    request_deserializer=gateway_dot_evaluation__pb2.ValidateAssertionsRequest.FromString,
                    response_serializer=gateway_dot_evaluation__pb2.ValidateAssertionsResponse.SerializeToString,
            ),
            'PreviewEvaluator': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewEvaluator,
                    request_deserializer=gateway_dot_evaluator__pb2.PreviewEvaluatorRequest.FromString,
                    response_serializer=gateway_dot_evaluator__pb2.PreviewEvaluatorResponse.SerializeToString,
            ),
            'PreviewEvaluation': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewEvaluation,
                    request_deserializer=gateway_dot_evaluation__pb2.PreviewEvaluationRequest.FromString,
                    response_serializer=gateway_dot_evaluation__pb2.PreviewEvaluationResponse.SerializeToString,
            ),
            'TestEvaluation': grpc.unary_unary_rpc_method_handler(
                    servicer.TestEvaluation,
                    request_deserializer=gateway_dot_evaluation__pb2.TestEvaluationRequest.FromString,
                    response_serializer=gateway_dot_evaluation__pb2.PreviewEvaluationResponse.SerializeToString,
            ),
            'GetInferenceLog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInferenceLog,
                    request_deserializer=gateway_dot_inference__log__pb2.GetInferenceLogRequest.FromString,
                    response_serializer=gateway_dot_inference__log__pb2.InferenceLog.SerializeToString,
            ),
            'ListInferenceLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInferenceLogs,
                    request_deserializer=gateway_dot_inference__log__pb2.ListInferenceLogsRequest.FromString,
                    response_serializer=gateway_dot_inference__log__pb2.ListInferenceLogsResponse.SerializeToString,
            ),
            'DeleteInferenceLog': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInferenceLog,
                    request_deserializer=gateway_dot_inference__log__pb2.DeleteInferenceLogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetDeploymentPrerequisites': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentPrerequisites,
                    request_deserializer=gateway_dot_deployment__pb2.GetDeploymentPrerequisitesRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.DeploymentPrerequisites.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'gateway.Gateway', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('gateway.Gateway', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Gateway(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetOAuthArguments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetOAuthArguments',
            gateway_dot_sign__in__pb2.GetOAuthArgumentsRequest.SerializeToString,
            gateway_dot_sign__in__pb2.GetOAuthArgumentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateAccount',
            gateway_dot_account__pb2.CreateAccountRequest.SerializeToString,
            gateway_dot_account__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetAccount',
            gateway_dot_account__pb2.GetAccountRequest.SerializeToString,
            gateway_dot_account__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListAccounts',
            gateway_dot_account__pb2.ListAccountsRequest.SerializeToString,
            gateway_dot_account__pb2.ListAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateAccount',
            gateway_dot_account__pb2.UpdateAccountRequest.SerializeToString,
            gateway_dot_account__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteAccount',
            gateway_dot_account__pb2.DeleteAccountRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetBalance',
            gateway_dot_billing__pb2.GetBalanceRequest.SerializeToString,
            gateway_dot_billing__pb2.Balance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPaymentMethods(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListPaymentMethods',
            gateway_dot_billing__pb2.ListPaymentMethodsRequest.SerializeToString,
            gateway_dot_billing__pb2.ListPaymentMethodsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListCosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListCosts',
            gateway_dot_billing__pb2.ListCostsRequest.SerializeToString,
            gateway_dot_billing__pb2.ListCostsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListInvoices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListInvoices',
            gateway_dot_billing__pb2.ListInvoicesRequest.SerializeToString,
            gateway_dot_billing__pb2.ListInvoicesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportBillingMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ExportBillingMetrics',
            gateway_dot_billing__pb2.ExportBillingMetricsRequest.SerializeToString,
            gateway_dot_billing__pb2.ExportBillingMetricsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTotalHistoricalSpend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetTotalHistoricalSpend',
            gateway_dot_billing__pb2.GetTotalHistoricalSpendRequest.SerializeToString,
            gateway_dot_billing__pb2.GetTotalHistoricalSpendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateBatchJob',
            gateway_dot_batch__job__pb2.CreateBatchJobRequest.SerializeToString,
            gateway_dot_batch__job__pb2.BatchJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetBatchJob',
            gateway_dot_batch__job__pb2.GetBatchJobRequest.SerializeToString,
            gateway_dot_batch__job__pb2.BatchJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListBatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListBatchJobs',
            gateway_dot_batch__job__pb2.ListBatchJobsRequest.SerializeToString,
            gateway_dot_batch__job__pb2.ListBatchJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateBatchJob',
            gateway_dot_batch__job__pb2.UpdateBatchJobRequest.SerializeToString,
            gateway_dot_batch__job__pb2.BatchJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteBatchJob',
            gateway_dot_batch__job__pb2.DeleteBatchJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchDeleteBatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/BatchDeleteBatchJobs',
            gateway_dot_batch__job__pb2.BatchDeleteBatchJobsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CancelBatchJob',
            gateway_dot_batch__job__pb2.CancelBatchJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateCluster',
            gateway_dot_cluster__pb2.CreateClusterRequest.SerializeToString,
            gateway_dot_cluster__pb2.Cluster.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetCluster',
            gateway_dot_cluster__pb2.GetClusterRequest.SerializeToString,
            gateway_dot_cluster__pb2.Cluster.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListClusters',
            gateway_dot_cluster__pb2.ListClustersRequest.SerializeToString,
            gateway_dot_cluster__pb2.ListClustersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateCluster',
            gateway_dot_cluster__pb2.UpdateClusterRequest.SerializeToString,
            gateway_dot_cluster__pb2.Cluster.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteCluster',
            gateway_dot_cluster__pb2.DeleteClusterRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetClusterConnectionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetClusterConnectionInfo',
            gateway_dot_cluster__pb2.GetClusterConnectionInfoRequest.SerializeToString,
            gateway_dot_cluster__pb2.ClusterConnectionInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateEnvironment',
            gateway_dot_environment__pb2.CreateEnvironmentRequest.SerializeToString,
            gateway_dot_environment__pb2.Environment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetEnvironment',
            gateway_dot_environment__pb2.GetEnvironmentRequest.SerializeToString,
            gateway_dot_environment__pb2.Environment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListEnvironments',
            gateway_dot_environment__pb2.ListEnvironmentsRequest.SerializeToString,
            gateway_dot_environment__pb2.ListEnvironmentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateEnvironment',
            gateway_dot_environment__pb2.UpdateEnvironmentRequest.SerializeToString,
            gateway_dot_environment__pb2.Environment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteEnvironment',
            gateway_dot_environment__pb2.DeleteEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchDeleteEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/BatchDeleteEnvironments',
            gateway_dot_environment__pb2.BatchDeleteEnvironmentsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConnectEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ConnectEnvironment',
            gateway_dot_environment__pb2.ConnectEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisconnectEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DisconnectEnvironment',
            gateway_dot_environment__pb2.DisconnectEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFeatureFlag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetFeatureFlag',
            gateway_dot_feature__flag__pb2.GetFeatureFlagRequest.SerializeToString,
            gateway_dot_feature__flag__pb2.FeatureFlag.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListFeatureFlags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListFeatureFlags',
            gateway_dot_feature__flag__pb2.ListFeatureFlagsRequest.SerializeToString,
            gateway_dot_feature__flag__pb2.ListFeatureFlagsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateSnapshot',
            gateway_dot_snapshot__pb2.CreateSnapshotRequest.SerializeToString,
            gateway_dot_snapshot__pb2.Snapshot.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetSnapshot',
            gateway_dot_snapshot__pb2.GetSnapshotRequest.SerializeToString,
            gateway_dot_snapshot__pb2.Snapshot.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSnapshots(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListSnapshots',
            gateway_dot_snapshot__pb2.ListSnapshotsRequest.SerializeToString,
            gateway_dot_snapshot__pb2.ListSnapshotsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteSnapshot',
            gateway_dot_snapshot__pb2.DeleteSnapshotRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBatchJobLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetBatchJobLogs',
            gateway_dot_batch__job__pb2.GetBatchJobLogsRequest.SerializeToString,
            gateway_dot_batch__job__pb2.GetBatchJobLogsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateNodePool',
            gateway_dot_node__pool__pb2.CreateNodePoolRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePool.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetNodePool',
            gateway_dot_node__pool__pb2.GetNodePoolRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePool.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListNodePools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListNodePools',
            gateway_dot_node__pool__pb2.ListNodePoolsRequest.SerializeToString,
            gateway_dot_node__pool__pb2.ListNodePoolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateNodePool',
            gateway_dot_node__pool__pb2.UpdateNodePoolRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePool.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteNodePool',
            gateway_dot_node__pool__pb2.DeleteNodePoolRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchDeleteNodePools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/BatchDeleteNodePools',
            gateway_dot_node__pool__pb2.BatchDeleteNodePoolsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNodePoolStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetNodePoolStats',
            gateway_dot_node__pool__pb2.GetNodePoolStatsRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePoolStats.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateUser',
            gateway_dot_user__pb2.CreateUserRequest.SerializeToString,
            gateway_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetUser',
            gateway_dot_user__pb2.GetUserRequest.SerializeToString,
            gateway_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListUsers',
            gateway_dot_user__pb2.ListUsersRequest.SerializeToString,
            gateway_dot_user__pb2.ListUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateUser',
            gateway_dot_user__pb2.UpdateUserRequest.SerializeToString,
            gateway_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteUser',
            gateway_dot_user__pb2.DeleteUserRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAuditLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListAuditLogs',
            gateway_dot_audit__log__pb2.ListAuditLogsRequest.SerializeToString,
            gateway_dot_audit__log__pb2.ListAuditLogsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateApiKey',
            gateway_dot_api__key__pb2.CreateApiKeyRequest.SerializeToString,
            gateway_dot_api__key__pb2.ApiKey.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListApiKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListApiKeys',
            gateway_dot_api__key__pb2.ListApiKeysRequest.SerializeToString,
            gateway_dot_api__key__pb2.ListApiKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteApiKey',
            gateway_dot_api__key__pb2.DeleteApiKeyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetInternalApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetInternalApiKey',
            gateway_dot_api__key__pb2.GetInternalApiKeyRequest.SerializeToString,
            gateway_dot_api__key__pb2.ApiKey.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateModel',
            gateway_dot_model__pb2.CreateModelRequest.SerializeToString,
            gateway_dot_model__pb2.Model.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetModel',
            gateway_dot_model__pb2.GetModelRequest.SerializeToString,
            gateway_dot_model__pb2.Model.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListModels',
            gateway_dot_model__pb2.ListModelsRequest.SerializeToString,
            gateway_dot_model__pb2.ListModelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListServerlessLoraModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListServerlessLoraModels',
            gateway_dot_model__pb2.ListServerlessLoraModelsRequest.SerializeToString,
            gateway_dot_model__pb2.ListServerlessLoraModelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateModel',
            gateway_dot_model__pb2.UpdateModelRequest.SerializeToString,
            gateway_dot_model__pb2.Model.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteModel',
            gateway_dot_model__pb2.DeleteModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetModelUploadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetModelUploadEndpoint',
            gateway_dot_model__pb2.GetModelUploadEndpointRequest.SerializeToString,
            gateway_dot_model__pb2.GetModelUploadEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetModelDownloadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetModelDownloadEndpoint',
            gateway_dot_model__pb2.GetModelDownloadEndpointRequest.SerializeToString,
            gateway_dot_model__pb2.GetModelDownloadEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateModelUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ValidateModelUpload',
            gateway_dot_model__pb2.ValidateModelUploadRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateModelConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ValidateModelConfig',
            gateway_dot_model__pb2.ValidateModelConfigRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ImportModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ImportModel',
            gateway_dot_model__pb2.ImportModelRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateDeployment',
            gateway_dot_deployment__pb2.CreateDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDeployment',
            gateway_dot_deployment__pb2.GetDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListDeployments',
            gateway_dot_deployment__pb2.ListDeploymentsRequest.SerializeToString,
            gateway_dot_deployment__pb2.ListDeploymentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateDeployment',
            gateway_dot_deployment__pb2.UpdateDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteDeployment',
            gateway_dot_deployment__pb2.DeleteDeploymentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UndeleteDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UndeleteDeployment',
            gateway_dot_deployment__pb2.UndeleteDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScaleDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ScaleDeployment',
            gateway_dot_deployment__pb2.ScaleDeploymentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDeploymentMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDeploymentMetrics',
            gateway_dot_deployment__pb2.GetDeploymentMetricsRequest.SerializeToString,
            gateway_dot_deployment__pb2.GetDeploymentMetricsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDeploymentTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateDeploymentTemplate',
            gateway_dot_deployment__template__pb2.CreateDeploymentTemplateRequest.SerializeToString,
            gateway_dot_deployment__template__pb2.DeploymentTemplate.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDeploymentTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDeploymentTemplate',
            gateway_dot_deployment__template__pb2.GetDeploymentTemplateRequest.SerializeToString,
            gateway_dot_deployment__template__pb2.DeploymentTemplate.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDeploymentTemplates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListDeploymentTemplates',
            gateway_dot_deployment__template__pb2.ListDeploymentTemplatesRequest.SerializeToString,
            gateway_dot_deployment__template__pb2.ListDeploymentTemplatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDeploymentTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateDeploymentTemplate',
            gateway_dot_deployment__template__pb2.UpdateDeploymentTemplateRequest.SerializeToString,
            gateway_dot_deployment__template__pb2.DeploymentTemplate.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDeploymentTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteDeploymentTemplate',
            gateway_dot_deployment__template__pb2.DeleteDeploymentTemplateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDeployedModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateDeployedModel',
            gateway_dot_deployed__model__pb2.CreateDeployedModelRequest.SerializeToString,
            gateway_dot_deployed__model__pb2.DeployedModel.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDeployedModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDeployedModel',
            gateway_dot_deployed__model__pb2.GetDeployedModelRequest.SerializeToString,
            gateway_dot_deployed__model__pb2.DeployedModel.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDeployedModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListDeployedModels',
            gateway_dot_deployed__model__pb2.ListDeployedModelsRequest.SerializeToString,
            gateway_dot_deployed__model__pb2.ListDeployedModelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDeployedModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateDeployedModel',
            gateway_dot_deployed__model__pb2.UpdateDeployedModelRequest.SerializeToString,
            gateway_dot_deployed__model__pb2.DeployedModel.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDeployedModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteDeployedModel',
            gateway_dot_deployed__model__pb2.DeleteDeployedModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAwsIamRoleBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateAwsIamRoleBinding',
            gateway_dot_aws__iam__role__binding__pb2.CreateAwsIamRoleBindingRequest.SerializeToString,
            gateway_dot_aws__iam__role__binding__pb2.AwsIamRoleBinding.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAwsIamRoleBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListAwsIamRoleBindings',
            gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsRequest.SerializeToString,
            gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteAwsIamRoleBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteAwsIamRoleBinding',
            gateway_dot_aws__iam__role__binding__pb2.DeleteAwsIamRoleBindingRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNodePoolBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateNodePoolBinding',
            gateway_dot_node__pool__binding__pb2.CreateNodePoolBindingRequest.SerializeToString,
            gateway_dot_node__pool__binding__pb2.NodePoolBinding.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListNodePoolBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListNodePoolBindings',
            gateway_dot_node__pool__binding__pb2.ListNodePoolBindingsRequest.SerializeToString,
            gateway_dot_node__pool__binding__pb2.ListNodePoolBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteNodePoolBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteNodePoolBinding',
            gateway_dot_node__pool__binding__pb2.DeleteNodePoolBindingRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateDataset',
            gateway_dot_dataset__pb2.CreateDatasetRequest.SerializeToString,
            gateway_dot_dataset__pb2.Dataset.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDataset',
            gateway_dot_dataset__pb2.GetDatasetRequest.SerializeToString,
            gateway_dot_dataset__pb2.Dataset.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListDatasets',
            gateway_dot_dataset__pb2.ListDatasetsRequest.SerializeToString,
            gateway_dot_dataset__pb2.ListDatasetsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateDataset',
            gateway_dot_dataset__pb2.UpdateDatasetRequest.SerializeToString,
            gateway_dot_dataset__pb2.Dataset.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteDataset',
            gateway_dot_dataset__pb2.DeleteDatasetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UploadDataset',
            gateway_dot_dataset__pb2.UploadDatasetRequest.SerializeToString,
            gateway_dot_dataset__pb2.UploadDatasetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatasetUploadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDatasetUploadEndpoint',
            gateway_dot_dataset__pb2.GetDatasetUploadEndpointRequest.SerializeToString,
            gateway_dot_dataset__pb2.GetDatasetUploadEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateDatasetUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ValidateDatasetUpload',
            gateway_dot_dataset__pb2.ValidateDatasetUploadRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatasetDownloadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDatasetDownloadEndpoint',
            gateway_dot_dataset__pb2.GetDatasetDownloadEndpointRequest.SerializeToString,
            gateway_dot_dataset__pb2.GetDatasetDownloadEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreviewDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/PreviewDataset',
            gateway_dot_dataset__pb2.PreviewDatasetRequest.SerializeToString,
            gateway_dot_dataset__pb2.PreviewDatasetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateEvaluator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateEvaluator',
            gateway_dot_evaluator__pb2.CreateEvaluatorRequest.SerializeToString,
            gateway_dot_evaluator__pb2.Evaluator.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEvaluator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetEvaluator',
            gateway_dot_evaluator__pb2.GetEvaluatorRequest.SerializeToString,
            gateway_dot_evaluator__pb2.Evaluator.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListEvaluators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListEvaluators',
            gateway_dot_evaluator__pb2.ListEvaluatorsRequest.SerializeToString,
            gateway_dot_evaluator__pb2.ListEvaluatorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteEvaluator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteEvaluator',
            gateway_dot_evaluator__pb2.DeleteEvaluatorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateEvaluation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateEvaluation',
            gateway_dot_evaluation__pb2.CreateEvaluationRequest.SerializeToString,
            gateway_dot_evaluation__pb2.Evaluation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEvaluation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetEvaluation',
            gateway_dot_evaluation__pb2.GetEvaluationRequest.SerializeToString,
            gateway_dot_evaluation__pb2.Evaluation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListEvaluations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListEvaluations',
            gateway_dot_evaluation__pb2.ListEvaluationsRequest.SerializeToString,
            gateway_dot_evaluation__pb2.ListEvaluationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteEvaluation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteEvaluation',
            gateway_dot_evaluation__pb2.DeleteEvaluationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateEvaluationJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateEvaluationJob',
            gateway_dot_evaluation__job__pb2.CreateEvaluationJobRequest.SerializeToString,
            gateway_dot_evaluation__job__pb2.EvaluationJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEvaluationJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetEvaluationJob',
            gateway_dot_evaluation__job__pb2.GetEvaluationJobRequest.SerializeToString,
            gateway_dot_evaluation__job__pb2.EvaluationJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListEvaluationJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListEvaluationJobs',
            gateway_dot_evaluation__job__pb2.ListEvaluationJobsRequest.SerializeToString,
            gateway_dot_evaluation__job__pb2.ListEvaluationJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteEvaluationJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteEvaluationJob',
            gateway_dot_evaluation__job__pb2.DeleteEvaluationJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateFineTuningJob',
            gateway_dot_fine__tuning__job__pb2.CreateFineTuningJobRequest.SerializeToString,
            gateway_dot_fine__tuning__job__pb2.FineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetFineTuningJob',
            gateway_dot_fine__tuning__job__pb2.GetFineTuningJobRequest.SerializeToString,
            gateway_dot_fine__tuning__job__pb2.FineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListFineTuningJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListFineTuningJobs',
            gateway_dot_fine__tuning__job__pb2.ListFineTuningJobsRequest.SerializeToString,
            gateway_dot_fine__tuning__job__pb2.ListFineTuningJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateFineTuningJob',
            gateway_dot_fine__tuning__job__pb2.UpdateFineTuningJobRequest.SerializeToString,
            gateway_dot_fine__tuning__job__pb2.FineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteFineTuningJob',
            gateway_dot_fine__tuning__job__pb2.DeleteFineTuningJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSupervisedFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateSupervisedFineTuningJob',
            gateway_dot_supervised__fine__tuning__job__pb2.CreateSupervisedFineTuningJobRequest.SerializeToString,
            gateway_dot_supervised__fine__tuning__job__pb2.SupervisedFineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSupervisedFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetSupervisedFineTuningJob',
            gateway_dot_supervised__fine__tuning__job__pb2.GetSupervisedFineTuningJobRequest.SerializeToString,
            gateway_dot_supervised__fine__tuning__job__pb2.SupervisedFineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSupervisedFineTuningJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListSupervisedFineTuningJobs',
            gateway_dot_supervised__fine__tuning__job__pb2.ListSupervisedFineTuningJobsRequest.SerializeToString,
            gateway_dot_supervised__fine__tuning__job__pb2.ListSupervisedFineTuningJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteSupervisedFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteSupervisedFineTuningJob',
            gateway_dot_supervised__fine__tuning__job__pb2.DeleteSupervisedFineTuningJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateReinforcementFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateReinforcementFineTuningJob',
            gateway_dot_reinforcement__fine__tuning__job__pb2.CreateReinforcementFineTuningJobRequest.SerializeToString,
            gateway_dot_reinforcement__fine__tuning__job__pb2.ReinforcementFineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReinforcementFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetReinforcementFineTuningJob',
            gateway_dot_reinforcement__fine__tuning__job__pb2.GetReinforcementFineTuningJobRequest.SerializeToString,
            gateway_dot_reinforcement__fine__tuning__job__pb2.ReinforcementFineTuningJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListReinforcementFineTuningJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListReinforcementFineTuningJobs',
            gateway_dot_reinforcement__fine__tuning__job__pb2.ListReinforcementFineTuningJobsRequest.SerializeToString,
            gateway_dot_reinforcement__fine__tuning__job__pb2.ListReinforcementFineTuningJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteReinforcementFineTuningJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteReinforcementFineTuningJob',
            gateway_dot_reinforcement__fine__tuning__job__pb2.DeleteReinforcementFineTuningJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateReinforcementFineTuningEpoch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateReinforcementFineTuningEpoch',
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.CreateReinforcementFineTuningEpochRequest.SerializeToString,
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.ReinforcementFineTuningEpoch.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReinforcementFineTuningEpoch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetReinforcementFineTuningEpoch',
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.GetReinforcementFineTuningEpochRequest.SerializeToString,
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.ReinforcementFineTuningEpoch.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListReinforcementFineTuningEpochs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListReinforcementFineTuningEpochs',
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.ListReinforcementFineTuningEpochsRequest.SerializeToString,
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.ListReinforcementFineTuningEpochsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteReinforcementFineTuningEpoch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteReinforcementFineTuningEpoch',
            gateway_dot_reinforcement__fine__tuning__epoch__pb2.DeleteReinforcementFineTuningEpochRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateRlorTrainerJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateRlorTrainerJob',
            gateway_dot_rlor__trainer__job__pb2.CreateRlorTrainerJobRequest.SerializeToString,
            gateway_dot_rlor__trainer__job__pb2.RlorTrainerJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRlorTrainerJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetRlorTrainerJob',
            gateway_dot_rlor__trainer__job__pb2.GetRlorTrainerJobRequest.SerializeToString,
            gateway_dot_rlor__trainer__job__pb2.RlorTrainerJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListRlorTrainerJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListRlorTrainerJobs',
            gateway_dot_rlor__trainer__job__pb2.ListRlorTrainerJobsRequest.SerializeToString,
            gateway_dot_rlor__trainer__job__pb2.ListRlorTrainerJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteRlorTrainerJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteRlorTrainerJob',
            gateway_dot_rlor__trainer__job__pb2.DeleteRlorTrainerJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreatePeftMergeJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreatePeftMergeJob',
            gateway_dot_peft__merge__job__pb2.CreatePeftMergeJobRequest.SerializeToString,
            gateway_dot_peft__merge__job__pb2.PeftMergeJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPeftMergeJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetPeftMergeJob',
            gateway_dot_peft__merge__job__pb2.GetPeftMergeJobRequest.SerializeToString,
            gateway_dot_peft__merge__job__pb2.PeftMergeJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPeftMergeJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListPeftMergeJobs',
            gateway_dot_peft__merge__job__pb2.ListPeftMergeJobsRequest.SerializeToString,
            gateway_dot_peft__merge__job__pb2.ListPeftMergeJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeletePeftMergeJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeletePeftMergeJob',
            gateway_dot_peft__merge__job__pb2.DeletePeftMergeJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetQuota(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetQuota',
            gateway_dot_quota__pb2.GetQuotaRequest.SerializeToString,
            gateway_dot_quota__pb2.Quota.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateQuota(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateQuota',
            gateway_dot_quota__pb2.UpdateQuotaRequest.SerializeToString,
            gateway_dot_quota__pb2.Quota.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListQuotas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListQuotas',
            gateway_dot_quota__pb2.ListQuotasRequest.SerializeToString,
            gateway_dot_quota__pb2.ListQuotasResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateSecret',
            gateway_dot_secret__pb2.CreateSecretRequest.SerializeToString,
            gateway_dot_secret__pb2.Secret.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetSecret',
            gateway_dot_secret__pb2.GetSecretRequest.SerializeToString,
            gateway_dot_secret__pb2.Secret.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSecrets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListSecrets',
            gateway_dot_secret__pb2.ListSecretsRequest.SerializeToString,
            gateway_dot_secret__pb2.ListSecretsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateSecret',
            gateway_dot_secret__pb2.UpdateSecretRequest.SerializeToString,
            gateway_dot_secret__pb2.Secret.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteSecret',
            gateway_dot_secret__pb2.DeleteSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReservation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetReservation',
            gateway_dot_reservation__pb2.GetReservationRequest.SerializeToString,
            gateway_dot_reservation__pb2.Reservation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListReservations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListReservations',
            gateway_dot_reservation__pb2.ListReservationsRequest.SerializeToString,
            gateway_dot_reservation__pb2.ListReservationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrepareModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/PrepareModel',
            gateway_dot_model__pb2.PrepareModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateBatchInferenceJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateBatchInferenceJob',
            gateway_dot_batch__inference__job__pb2.CreateBatchInferenceJobRequest.SerializeToString,
            gateway_dot_batch__inference__job__pb2.BatchInferenceJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBatchInferenceJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetBatchInferenceJob',
            gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobRequest.SerializeToString,
            gateway_dot_batch__inference__job__pb2.BatchInferenceJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListBatchInferenceJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListBatchInferenceJobs',
            gateway_dot_batch__inference__job__pb2.ListBatchInferenceJobsRequest.SerializeToString,
            gateway_dot_batch__inference__job__pb2.ListBatchInferenceJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateBatchInferenceJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/UpdateBatchInferenceJob',
            gateway_dot_batch__inference__job__pb2.UpdateBatchInferenceJobRequest.SerializeToString,
            gateway_dot_batch__inference__job__pb2.BatchInferenceJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteBatchInferenceJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteBatchInferenceJob',
            gateway_dot_batch__inference__job__pb2.DeleteBatchInferenceJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateEagleTrainingJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateEagleTrainingJob',
            gateway_dot_eagle__training__job__pb2.CreateEagleTrainingJobRequest.SerializeToString,
            gateway_dot_eagle__training__job__pb2.EagleTrainingJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEagleTrainingJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetEagleTrainingJob',
            gateway_dot_eagle__training__job__pb2.GetEagleTrainingJobRequest.SerializeToString,
            gateway_dot_eagle__training__job__pb2.EagleTrainingJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListEagleTrainingJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListEagleTrainingJobs',
            gateway_dot_eagle__training__job__pb2.ListEagleTrainingJobsRequest.SerializeToString,
            gateway_dot_eagle__training__job__pb2.ListEagleTrainingJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteEagleTrainingJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteEagleTrainingJob',
            gateway_dot_eagle__training__job__pb2.DeleteEagleTrainingJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBatchInferenceJobInputUploadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetBatchInferenceJobInputUploadEndpoint',
            gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobInputUploadEndpointRequest.SerializeToString,
            gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobInputUploadEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBatchInferenceJobOutputDownloadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetBatchInferenceJobOutputDownloadEndpoint',
            gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobOutputDownloadEndpointRequest.SerializeToString,
            gateway_dot_batch__inference__job__pb2.GetBatchInferenceJobOutputDownloadEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateBatchInferenceJobInputUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ValidateBatchInferenceJobInputUpload',
            gateway_dot_batch__inference__job__pb2.ValidateBatchInferenceJobInputUploadRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDatasetValidationJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/CreateDatasetValidationJob',
            gateway_dot_dataset__validation__job__pb2.CreateDatasetValidationJobRequest.SerializeToString,
            gateway_dot_dataset__validation__job__pb2.DatasetValidationJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatasetValidationJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDatasetValidationJob',
            gateway_dot_dataset__validation__job__pb2.GetDatasetValidationJobRequest.SerializeToString,
            gateway_dot_dataset__validation__job__pb2.DatasetValidationJob.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDatasetValidationJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListDatasetValidationJobs',
            gateway_dot_dataset__validation__job__pb2.ListDatasetValidationJobsRequest.SerializeToString,
            gateway_dot_dataset__validation__job__pb2.ListDatasetValidationJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDatasetValidationJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteDatasetValidationJob',
            gateway_dot_dataset__validation__job__pb2.DeleteDatasetValidationJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateAssertions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ValidateAssertions',
            gateway_dot_evaluation__pb2.ValidateAssertionsRequest.SerializeToString,
            gateway_dot_evaluation__pb2.ValidateAssertionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreviewEvaluator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/PreviewEvaluator',
            gateway_dot_evaluator__pb2.PreviewEvaluatorRequest.SerializeToString,
            gateway_dot_evaluator__pb2.PreviewEvaluatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreviewEvaluation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/PreviewEvaluation',
            gateway_dot_evaluation__pb2.PreviewEvaluationRequest.SerializeToString,
            gateway_dot_evaluation__pb2.PreviewEvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TestEvaluation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/TestEvaluation',
            gateway_dot_evaluation__pb2.TestEvaluationRequest.SerializeToString,
            gateway_dot_evaluation__pb2.PreviewEvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetInferenceLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetInferenceLog',
            gateway_dot_inference__log__pb2.GetInferenceLogRequest.SerializeToString,
            gateway_dot_inference__log__pb2.InferenceLog.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListInferenceLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/ListInferenceLogs',
            gateway_dot_inference__log__pb2.ListInferenceLogsRequest.SerializeToString,
            gateway_dot_inference__log__pb2.ListInferenceLogsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteInferenceLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/DeleteInferenceLog',
            gateway_dot_inference__log__pb2.DeleteInferenceLogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDeploymentPrerequisites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/gateway.Gateway/GetDeploymentPrerequisites',
            gateway_dot_deployment__pb2.GetDeploymentPrerequisitesRequest.SerializeToString,
            gateway_dot_deployment__pb2.DeploymentPrerequisites.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
